# -*- coding: utf-8 -*-

import logging
import formencode

from pylons import request, tmpl_context as c
from mpulsweb.lib.translation import _

from mpulsweb.lib.db import db
from mpulsweb.lib.base import BaseController, render, redirect_to, session
from mpulsweb.lib.helpers import url_for
from mpulsweb.lib.security import checkRole, getDbName
from mpulsweb.lib.validators import ValidatorStateObject, NewUserGroupForm, \
    EditUserGroupForm , NewUserForm, EditUserForm, DeleteUserHelperForm
from mpulsweb.model.user import UserListObject, UserObject, UserGroupList, \
    UserGroup, UserGroupFactory
from mpulsweb.model.case import MpulsCaseOverview, MpulsCaseBundle
from mpulsweb.model.phase import PhaseFactory 
from mpulsweb.controllers.case_overview import default_phases


RESET_PASSWORD_CONFIRM = _('adm_reset_user_password')
RESET_PASSWORD_CONFIRM_QUESTION = _('adm_reset_user_password_question')
EDIT_USER_SUCCESS_HEADER = _('adm_edit_user_header')
EDIT_USER_SUCCESS_TEXT = _('adm_edit_user_text')
DELETE_USER_CONFIRM = _('adm_delete_user_confirm_header')
DELETE_USER_CONFIRM_QUESTION = _('adm_delete_user_confirm_text')
DELETE_USER_SUCCESS_HEADER = _('adm_delete_user_success_header')
DELETE_USER_SUCCESS_TEXT = _('adm_delete_user_success_text')
DELETE_SELFUSER_FAILURE = _('adm_delete_selfuser_notification_header')
DELETE_SELFUSER_FAILURE_TEXT = _('adm_delete_selfuser_notification_text')
DELETE_USER_HASCASES = _(u'Der Benutzer konnte nicht gelöscht werden')
DELETE_USER_HASCASES_TEXT = \
_(u'Der Benutzer konnte nicht gelöscht werden, da dieser noch Bearbeiter'
  u' von mindestens einen Fall ist. Bitte übertragen Sie zunächst'
  u' sämtliche Fälle dieses Nutzers an einen anderen Bearbeiter und'
  u' wiederholen Sie den Vorgang erneut. Klicken Sie auf "OK", um zur'
  u' Benutzerübersicht zurück zu kehren.')
DIALOG_CONFIRM_SETEDITOR = _('adm_set_editor_header')
SETEDITOR_NOTIFICATION_SUCCESS = _('adm_set_editor_success_text')
SETEDITOR_NOTIFICATION_SUCCESS_REST = _('adm_set_editor_success_text_rest')
SETEDITOR_NOTIFICATION_SUCCESS_HEAD = _('adm_set_editor_success_text_head')
SETEDITOR_NOTIFICATION_SUCCESS_REST_HEAD = \
                                  _('adm_set_editor_success_text_rest_head')

NEW_USERGROUP_SUCCESS_HEADER = _('adm_new_usergroup_success_header')
NEW_USERGROUP_SUCCESS_TEXT = _('adm_new_usergroup_success_text')
NEW_USERGROUP_FAILURE_HEADER = _('adm_new_usergroup_failure_header')
NEW_USERGROUP_FAILURE_TEXT = _('adm_new_usergroup_failure_text')
EDIT_USERGROUP_SUCCESS_HEADER = _('adm_edit_usergroup_header')
EDIT_USERGROUP_SUCCESS_TEXT = _('adm_edit_usergroup_text')
DELETE_USERGROUP_CONFIRM = _('adm_delete_usergroup_confirm_header')
DELETE_USERGROUP_CONFIRM_QUESTION = _('adm_delete_usergroup_confirm_text')
DELETE_USERGROUP_SUCCESS_HEADER = _('adm_delete_usergroup_success_header')
DELETE_USERGROUP_SUCCESS_TEXT = _('adm_delete_usergroup_success_text')
DELETE_USERGROUP_FAILED_HEADER = _('adm_delete_usergroup_failure_header')
DELETE_USERGROUP_FAILED_TEXT = _('adm_delete_usergroup_failure_text')


log = logging.getLogger(__name__)


def user_has_cases(user):
    conn, cur = None, None
    fields = {'userid': user.id}
    sql = ("select count(id) from master_tbl_view"
           " where bearbeiter_id = %(userid)s")
    try:
        conn = db.getConnection()
        cur = conn.cursor()
        cur.execute(sql, fields)
        result = cur.fetchone()
        return int(result[0]) > 0
    except Exception, e:
        log.exception(e)
        return True
    finally:
        db.recycleConnection(conn, cur)


class AdministrationController(BaseController):

    @checkRole('admin_ka')
    def index(self):
        return self.overviewUser()

    # USER
    @checkRole('admin_ka')
    def overviewUser(self):
        list = UserListObject()
        c.user_overview = list.getUserList()
        return render('/administration/overview_user.mako')

    @checkRole('admin_ka')
    def newUser(self):
        c.form_errors = {}
        c.form_result = {}
        return render('/administration/new_user.mako')

    @checkRole('admin_ka')
    def newUserAction(self):
        validator = NewUserForm()
        c.user_password = None
        try:
            agency = getDbName()
            state = ValidatorStateObject()
            state.agency = agency
            c.form_result = validator.to_python(request.params, state)
            c.uo = UserObject()
            # Set initial data which is needed to create a new user
            login = c.form_result.get('login', '')
            role = c.form_result.get('role', '')
            c.uo.setData(c.form_result)
            # create user
            c.user_password = c.uo.createLogin(login, role, agency)
            return render('/administration/new_user_result.mako')
        except formencode.Invalid, error:
            c.form_result = error.value
            c.form_errors = error.error_dict or {}
            form = render('/administration/new_user.mako')
            return formencode.htmlfill.render(form,
                                              c.form_result, c.form_errors,
                                              auto_insert_errors=False)

    @checkRole('admin_ka')
    def showUser(self, id=None):
        id = self._checkInt(id)
        c.uo = UserObject(id)
        c.vuo = UserGroup(c.uo.standin)
        return render('/administration/show_user.mako')

    @checkRole('admin_ka')
    def editUser(self, id=None):
        id = self._checkInt(id)
        c.form_errors = {}
        c.form_result = {}
        c.uo = UserObject(id)
        return render('/administration/edit_user.mako')

    @checkRole('admin_ka')
    def editUserAction(self):
        validator = EditUserForm()
        try:
            uid = request.params['uid']
            c.uo = UserObject(uid)
            form_result = validator.to_python(request.params)
            c.uo.setData(form_result)
            c.uo.store()
            c.dialog_title = EDIT_USER_SUCCESS_HEADER
            c.dialog_text = EDIT_USER_SUCCESS_TEXT
            c.url_ok = url_for(controller='/administration',
                               action='overviewUser')
            return render('/administration/dialogs/success_edit_user.mako')
        except formencode.Invalid, error:
            c.form_result = error.value
            c.form_errors = error.error_dict or {}
            return render('/administration/edit_user.mako')

    @checkRole('admin_ka')
    def resetUserPassword(self, id=None, confirmed='0'):
        id = self._checkInt(id)
        confirmed = self._checkBool(confirmed)
        c.uo = UserObject(id)
        if confirmed:
            c.new_password = c.uo.resetPassword()
            return render('/administration/reset_password.mako')
        else:
            c.context = "../main.mako"
            c.dialog_title = RESET_PASSWORD_CONFIRM
            c.dialog_text = "%s %s, %s" % (RESET_PASSWORD_CONFIRM_QUESTION,
                                           c.uo.last_name, c.uo.first_name)

            c.url_yes = url_for(controller='/administration',
                                action='resetUserPassword', id=id, confirmed=1)
            c.url_no = url_for(controller='/administration',
                               action='showUser', id=id)
            return render('/administration/dialogs/confirm_resetpassword.mako')

    # Old deleteUser method, which does not raise a helper dialog to transfer
    # remaining cases to a another user before deletion. Simply raise an
    # error-dialog an cance action.

    #@checkRole('admin_ka')
    #def deleteUser(self, id, confirmed='0'):
    #    id = self._checkInt(id)
    #    confirmed = self._checkBool(confirmed)
    #    uo = UserObject(id)

    #    # Make sure that the user can not delete himself
    #    if uo.id == session.get('USER_AUTHORIZED').id:
    #        c.dialog_title = DELETE_SELFUSER_FAILURE
    #        c.dialog_text = DELETE_SELFUSER_FAILURE_TEXT
    #        c.url_ok = url_for(controller='/administration',
    #                           action='overviewUser')
    #        return render('/administration/dialogs/failed_delete_user.mako')

    #    if confirmed:
    #        # Check if there are cases for which the user is the editor. If
    #        # he is an editor then raise a error dialog
    #        if user_has_cases(uo):
    #            c.dialog_title = DELETE_USER_HASCASES
    #            c.dialog_text = DELETE_USER_HASCASES_TEXT
    #            c.url_ok = url_for(controller='/administration',
    #                               action='overviewUser')
    #            return render('/administration/dialogs/failed_delete_user.mako')
    #        else:
    #            uo.delete()
    #            c.dialog_title = DELETE_USER_SUCCESS_HEADER
    #            c.dialog_text = DELETE_USER_SUCCESS_TEXT
    #            c.url_ok = url_for(controller='/administration',
    #                               action='overviewUser')
    #            return render('/administration/dialogs/success_delete_user.mako')

    #    else:
    #        c.context = "../main.mako"
    #        c.dialog_title = DELETE_USER_CONFIRM
    #        c.dialog_text = DELETE_USER_CONFIRM_QUESTION % (uo.last_name,
    #                                                     uo.first_name,
    #                                                     uo.login)
    #        c.url_yes = url_for(controller='/administration',
    #                            action='deleteUser', id=id, confirmed=1)
    #        c.url_no = url_for(controller='/administration',
    #                           action='overviewUser')
    #        return render('/administration/dialogs/confirm_deleteuser.mako')

    @checkRole('admin')
    def deleteUser(self, id, confirmed='0'):
        id = self._checkInt(id)
        confirmed = self._checkBool(confirmed)
        uo = UserObject(id)
        # Make sure that the user can not delete himself
        if uo.id == session.get('USER_AUTHORIZED').id:
            c.failed_for = DELETE_SELFUSER_FAILURE
            c.failed_text = DELETE_SELFUSER_FAILURE_TEXT
            c.url_ok = url_for(controller='/administration',
                               action='overviewUser')
            return render('/administration/dialogs/failed_delete_user.mako')

        if confirmed:
            # Check if there are cases for which the user is the editor. If
            # he is an editor then raise a dialog which allows the user to
            # transfer the cases.
            overview = MpulsCaseOverview()
            phases = []
            for p in default_phases():
                phases.append('phase:%s' % p)
            overview.search('editor:%s;'
                            'state:1;state:2;state:3;state:4;state:5;%s'
                            % (uo.id, ";".join(phases)))
            if overview.getDatasets():
                list = UserListObject()
                filter = [u.id for u in list.getAdminList()]
                filter.append(uo.id) #the user we want to delete
                c.user_list = list.getUserList(filter)
                c.cases = overview
                c.phases = PhaseFactory().build() 
                print c.cases
                c.delete_user_id = id
                return render('/administration/delete_user_helper.mako')
            else:
                uo.delete()
                c.success_for = DELETE_USER_SUCCESS_HEADER
                c.success_text = DELETE_USER_SUCCESS_TEXT
                c.url_ok = url_for(controller='/administration',
                                   action='overviewUser')
                return render('/administration/dialogs/'
                              'success_delete_user.mako')

        else:
            c.context = "../main.mako"
            c.confirm_for = DELETE_USER_CONFIRM
            c.question = DELETE_USER_CONFIRM_QUESTION % (uo.last_name,
                                                         uo.first_name,
                                                         uo.login)
            c.url_yes = url_for(controller='/administration',
                                action='deleteUser', id=id, confirmed=1)
            c.url_no = url_for(controller='/administration',
                               action='overviewUser')
            return render('/administration/dialogs/confirm_deleteuser.mako')

    @checkRole('admin')
    def deleteUserHelper(self):
        validator = DeleteUserHelperForm()
        all_cases = MpulsCaseOverview()
        c.notification_for = DIALOG_CONFIRM_SETEDITOR
        c.form_errors = {}
        c.form_result = {}

        if 'editor' in request.params:
            try:
                data = formencode.variabledecode.variable_decode(request.params)
                form_result = validator.to_python(data)
                case_bundle = MpulsCaseBundle(form_result.get('case_id', []))
                new_editor = UserObject(form_result.get('editor'))
                del_user = UserObject(form_result.get('user_id'))
                all_cases.search('editor:%s;state:1;state:2;state:3;state:4;'
                                 'state:5' % del_user.id)
                num = case_bundle.setEditor(form_result.get('editor'))
                rest = all_cases.numDatasets() - case_bundle.numDatasets()
                c.url_ok = url_for(controller='/administration',
                                   action='deleteUser',
                                   id=form_result.get('user_id'), confirmed=1)
                c.success_for = SETEDITOR_NOTIFICATION_SUCCESS_HEAD
                if rest > 0:
                    c.success_for = SETEDITOR_NOTIFICATION_SUCCESS_REST_HEAD
                    c.success_text = (SETEDITOR_NOTIFICATION_SUCCESS_REST
                                      % (new_editor.first_name,
                                         new_editor.last_name,
                                         del_user.first_name,
                                         del_user.last_name))
                else:
                    c.success_for = SETEDITOR_NOTIFICATION_SUCCESS_HEAD
                    c.success_text = (SETEDITOR_NOTIFICATION_SUCCESS
                                      % (new_editor.first_name,
                                         new_editor.last_name,
                                         del_user.first_name,
                                         del_user.last_name))
                return render('/administration/dialogs/'
                              'notificate_delete_user_helper.mako')
            except formencode.Invalid, error:
                return self.deleteUser(form_result.get('user_id'), '1')
        else:
            redirect_to(controller="/administration", action='overviewUser')

    # USERGROUPS
    @checkRole('admin_ka')
    def overviewUserGroups(self):
        # Get gid of usergroups so we can filter them out.
        user = UserListObject()
        filter = [u.gid for u in user.getUserList()]

        list = UserGroupList()
        c.group_overview = list.getGroupList(filter)
        return render('/administration/overview_usergroups.mako')

    @checkRole('admin_ka')
    def newUserGroup(self):
        c.form_errors = {}
        c.form_result = {}
        return render('/administration/new_usergroup.mako')

    @checkRole('admin_ka')
    def newUserGroupAction(self):
        factory = UserGroupFactory()
        validator = NewUserGroupForm()
        try:
            c.form_result = validator.to_python(request.params)
            c.ugo = factory.create(c.form_result.get('name'))
            c.dialog_title = NEW_USERGROUP_SUCCESS_HEADER
            c.dialog_text = NEW_USERGROUP_SUCCESS_TEXT
            c.url_ok = url_for(controller='/administration',
                               action='overviewUserGroups')
            return render('/administration/dialogs/success_new_usergroup.mako')
        except formencode.Invalid, error:
            c.form_result = error.value
            c.form_errors = error.error_dict or {}
            form = render('/administration/new_usergroup.mako')
            return formencode.htmlfill.render(form,
                                              c.form_result,
                                              c.form_errors,
                                              auto_insert_errors=False)
        except Exception, e:
            log.exception(e)
            c.dialog_title = NEW_USERGROUP_FAILURE_HEADER
            c.dialog_text = NEW_USERGOUP_FAILURE_TEXT
            c.url_ok = url_for(controller='/administration',
                               action='overviewUserGroups')
            return render('/administration/dialogs/failed_new_usergroup.mako')

    @checkRole('admin_ka')
    def showUserGroup(self, id=None):
        factory = UserGroupFactory()
        id = self._checkInt(id)
        group = factory.load(id)
        groupmember = group.getUser()
        c.group = group
        c.groupmember = groupmember
        return render('/administration/show_usergroup.mako')

    @checkRole('admin_ka')
    def editUserGroup(self, id=None):
        id = self._checkInt(id)
        factory = UserGroupFactory()
        group = factory.load(id)
        memberlist = group.getUser().getUserList()
        c.form_errors = {}
        c.form_result = {'name': group.name,
                         'id': group.id,
                         'standin': [user.id for user in memberlist]}
        c.group = group
        userlist = UserListObject()
        admins = userlist.getAdminList()
        c.userlist = userlist.getUserList(filter=[u.id for u in admins])
        form = render('/administration/edit_usergroup.mako')
        return formencode.htmlfill.render(form,
                                          c.form_result, c.form_errors,
                                          auto_insert_errors=False)

    @checkRole('admin_ka')
    def editUserGroupAction(self):
        validator = EditUserGroupForm()
        factory = UserGroupFactory()
        userlist = UserListObject()
        admins = userlist.getAdminList()
        c.userlist = userlist.getUserList(filter=[u.id for u in admins])

        try:
            state = ValidatorStateObject()
            data = formencode.variabledecode.variable_decode(request.params)
            state.groupid = data.get('id')
            form_result = validator.to_python(data, state)
            group = factory.load(form_result.get('id'))
            group.setData(form_result)
            group.setUser(form_result.get('standin'))
            group.store()
            c.group = group
            c.dialog_title = EDIT_USERGROUP_SUCCESS_HEADER
            c.dialog_text = EDIT_USERGROUP_SUCCESS_TEXT
            c.url_ok = url_for(controller='/administration',
                               action='overviewUserGroups')
            return render('/administration/dialogs/success_edit_usergroup.mako')
        except formencode.Invalid, error:
            c.form_result = error.value
            c.group = factory.load(c.form_result.get('id'))
            c.form_errors = error.error_dict or {}
            form = render('/administration/edit_usergroup.mako')
            return formencode.htmlfill.render(form,
                                              c.form_result, c.form_errors,
                                              auto_insert_errors=False)

    @checkRole('admin_ka')
    def deleteUserGroup(self, id, confirmed='0'):
        id = self._checkInt(id)
        confirmed = self._checkBool(confirmed)
        factory = UserGroupFactory()
        try:
            ugo = factory.load(id)
            if confirmed:
                ugo.delete()
                c.dialog_title = DELETE_USERGROUP_SUCCESS_HEADER
                c.dialog_text = DELETE_USERGROUP_SUCCESS_TEXT
                c.url_ok = url_for(controller='/administration',
                                   action='overviewUserGroups')
                return render('/administration/dialogs/'
                              'success_deletegroup_user.mako')
            else:
                c.context = "../main.mako"
                c.dialog_title = DELETE_USERGROUP_CONFIRM
                c.dialog_text = DELETE_USERGROUP_CONFIRM_QUESTION
                c.url_yes = url_for(controller='/administration',
                                    action='deleteUserGroup', id=ugo.id,
                                    confirmed=1)
                c.url_no = url_for(controller='/administration',
                                   action='overviewUserGroups')
                return render('/administration/dialogs/'
                              'confirm_deleteusergroup.mako')
        except Exception, e:
            log.exception(e)
            c.dialog_title = DELETE_USERGROUP_FAILED_HEADER
            c.dialog_text = DELETE_USERGROUP_FAILED_TEXT
            c.url_ok = url_for(controller='/administration',
                               action='overviewUserGroups')
            return render('/administration/dialogs/failed_new_usergroup.mako')


# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
