import logging
import md5

from pylons import request, response, tmpl_context as c, h
from pylons.controllers.util import redirect_to

from mpulsweb.lib.base import BaseController, render, session, auth_cookie_name
from mpulsweb.lib.security import checkLogin, generateID, userIdentity

log = logging.getLogger(__name__)

class AuthController(BaseController):

    def index(self):
        return self.login()

    def logout(self):
        # XXX: invalidate() does not delete backend data :-/
        session.delete()
        session.save()
        session.invalidate()
        response.delete_cookie(auth_cookie_name())
        return render('/auth/logout.mako')

    def login(self):
        return render('/auth/login.mako')

    def loginAction(self):
        try:
            login = request.params.getone('username')
            passwd = request.params.getone('password')

            # Try to get the name of the db to connect to from the request
            # params and check if it is contained in the list of defined
            # databases. 
            dbname = request.params.get('dbname')
            if dbname:
                dblist = h.get_db_selectionlist()
                if dblist.has_key(dbname):
                    session['DB_NAME_FROM_LIST'] = dbname
                    session.save()
            
            # Check login
            user = checkLogin(login, passwd)
            if user:
                c.login_failed = False
                shared = generateID()
                session['USER_AUTHORIZED'] = user
                session['AUTH'] = md5.new(shared + userIdentity()).digest()
                session.save()

                # Does only work work with enabled ssl. secure means that the
                # cookie will only be sent over a secure connection.
                #response.set_cookie('mpuls_auth', shared, secure=True)
                response.set_cookie(auth_cookie_name(), shared)

                redirect_to("/")
            else:
                c.login_failed = True
                session.delete()
                session.save()
                session.invalidate()
                return self.login()
        except KeyError:
            log.error('Error while fetching username and password')
        return self.login()

    def accountDeactivated(self):
        try:
            del session['USER_AUTHORIZED']
            session.save()
        except KeyError:
            pass
        return render('/auth/account_deactivated.mako')
