# -*- coding: utf-8 -*-
#
# Copyright 2007, 2008 Intevation GmbH, Germany, <info@intevation.de>
# 
# This file is part of mpuls WASKA (CoMPUter-based case fiLeS - 
# Web-Anwendungs-Server fuer Kompetenzagenturen).
# 
# mpuls WASKA is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
# 
# mpuls WASKA is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
# 
# You should have received a copy of the GNU Affero General Public
# License along with mpuls WASKA. If not, see <http://www.gnu.org/licenses/>.
# 
# mpuls WASKA has been developed on behalf of the 
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
# European Social Fund resources.

import sys
import logging
import formencode
import traceback
from datetime import datetime

from pylons import app_globals as g

from mpulsweb.lib.translation import _, ungettext

from mpulsweb.lib.security import checkRole
from mpulsweb.model.logbook import Logbook, LogbookEntry, LogbookEntryChecker

from mpulsweb.lib.helpers import url_for
from mpulsweb.lib.base import BaseController, c, render, request, session
from mpulsweb.lib.validators import CreateLogbookForm, EditLogbookForm

LOGBOOK_ENTRY_CREATE_FAILED       = _(u"Logbook entry was not created!")
LOGBOOK_ENTRY_CREATE_FAILED_TEXT  = _(u"An error occured while creating a logbook entry")

CREATE_LOGBOOK_ENTRY_SUCCESS      = _(u"Entry successfully created.")
CREATE_LOGBOOK_ENTRY_SUCCESS_TEXT = _(u"The logbook entry was sucessfully created")

DELETE_LOGBOOK_ENTRY_CONFIRM      = _(u"Delete logbook entry?")
DELETE_LOGBOOK_ENTRY_CONFIRM_TEXT = _(u"""Do you want to delete this logbook entry?
The data will be irrevocably lost.""")

LOGBOOK_ENTRY_DELETE_SUCCESS      = _(u"Logbook entry successfully deleted!")
LOGBOOK_ENTRY_DELETE_SUCCESS_TEXT = _(u"Logbook entry was successfully deleted!")

LOGBOOK_ENTRY_DELETE_FAILED       = _(u"Deletion of logbook entry failed!")
LOGBOOK_ENTRY_DELETE_FAILED_TEXT  = _(u"An error occured while deleting the logbook entry.")

LOGBOOK_ENTRY_SHOW_FAILED         = _(u"Showing of logbook entry failed!")
LOGBOOK_ENTRY_SHOW_FAILED_TEXT    = _(u"An error occured while showing the logbook entry.")

LOGBOOK_ENTRY_SAVE_SUCCESS        = _(u"Changes on logbook successfull!")
LOGBOOK_ENTRY_SAVE_SUCCESS_TEXT   = _(u"The changes on the logbook entry were applied successfully.")

LOGBOOK_ENTRY_SAVE_FAILED         = _(u"Changes on logbook failed!")
LOGBOOK_ENTRY_SAVE_FAILED_TEXT    = _(u"An error occured applying changes on the logbook entry")

log = logging.getLogger(__name__)

def get_sort(params):
    sort = params.get('sort_field', 'id')
    order = params.get('sort_order', 'asc')
    return sort, order

class LogbookController(BaseController):

    @checkRole(('cm_ka'))
    def index(self, id):
        return self.overview(id)

    def overview(self, id):
        sort, order = get_sort(request.params)
        id = self._checkInt(id)

        ## Load logbook
        logbook = Logbook()
        logbook.loadById(int(id), sort, order)
        c.logbook = logbook

        ## Build evaluations
        c.eval_effort = logbook.getEvaluation()
        c.eval_typ_effort = logbook.getTypEvaluation()
        
        return render('/logbook/overview.mako')

    @checkRole(('cm_ka'))
    def show(self, id):
        id = self._checkInt(id)
        try:
            entry = LogbookEntry()
            entry.loadById(id)
        except Exception, e:
            c.failed_for = LOGBOOK_ENTRY_SHOW_FAILED
            c.failed_text = LOGBOOK_ENTRY_SHOW_FAILED_TEXT
            c.url_ok = url_for(controller='/logbook', action='index',
                               id=session['case'].id)
            log.exception(e)
            return render('/logbook/dialogs/failed_show_logbook_entry.mako')

        c.entry = entry
        return render('/logbook/show.mako')

    @checkRole('cm_ka')
    def new(self, id):
        id = self._checkInt(id)

        entry = LogbookEntry()
        entry.setDate(datetime.now())
        entry.setKind(-1)

        form_defaults = {}
        c.form_errors = {}

        # Set the default values, also for all the "types" from the JSON file
        form_defaults['date'] = entry.getDate()
        form_defaults['time'] = entry.getTime()
        form_defaults['kind'] = entry.getKindAsInt()
        form_defaults['case_id'] = id
        for num, typ in enumerate(g.mpuls_config.get('logbook', 'types')):
            form_defaults[typ.get('db_field')] = -1  #only if it's a drop-down!

        form = render('/logbook/new.mako')
        return formencode.htmlfill.render(form,
                                          defaults=form_defaults,
                                          auto_insert_errors=False,
                                          errors=c.form_errors)

    @checkRole('cm_ka')
    def newAction(self):
        checker = LogbookEntryChecker(request.params)
        validator = CreateLogbookForm()
        c.form_errors = {}
        c.form_result = {}

        try:
            form_result = validator.to_python(request.params)
        except formencode.Invalid, error:
            c.form_result = error.value
            c.form_errors = error.error_dict or {}
            form = render('/logbook/new.mako')
            return formencode.htmlfill.render(form,
                                              defaults=c.form_result,
                                              auto_insert_errors=False,
                                              errors=c.form_errors)

        #if checker.hasErrors():
        #    c.ds_id           = session['case'].id
        #    c.entry           = checker.getLogbookEntry()
        #    c.form_errors     = checker.getErrors()

        try:
            log.debug("New Logbook entry from case %s" % checker.getCaseId())
            logbook = Logbook(checker.getCaseId())
            entry = checker.getLogbookEntry()
            logbook.addEntry(entry)
            logbook.store(session['USER_AUTHORIZED'].id)
            c.url_ok = url_for(controller='/logbook', action='index',
                               id=session['case'].id)
            c.success_for = CREATE_LOGBOOK_ENTRY_SUCCESS
            c.success_text = CREATE_LOGBOOK_ENTRY_SUCCESS_TEXT
            return render('/logbook/dialogs/success_create_logbook_entry.mako')
        except:
            traceback.print_exc(file=sys.stderr)
            c.failed_for = LOGBOOK_ENTRY_CREATE_FAILED
            c.failed_text = LOGBOOK_ENTRY_CREATE_FAILED_TEXT
            c.url_ok = url_for(controller='/case', action='logbook',
                               id=session['case'].id)
            return render('/logbook/dialogs/failed_create_logbook_entry.mako')


    @checkRole('cm_ka')
    def edit(self, id):
        id = self._checkInt(id)
        c.form_errors = {}
        entry_data = {}
        try:
            entry = LogbookEntry()
            entry.loadById(id)
            entry_data['id'] = entry.id
            entry_data['date'] = entry.getDate()
            entry_data['time'] = entry.getTime()
            entry_data['duration'] = entry.getDuration()
            entry_data['art'] = entry.getKindAsInt()
            entry_data['notice'] = entry.getNotice()
            entry_data['typ'] = entry.getTyp()
            entry_data['short_notice'] = entry.getShortNotice()
            c.entry = entry
            form = render('/logbook/edit.mako')
            return formencode.htmlfill.render(form,
                                              defaults=entry_data,
                                              auto_insert_errors=False,
                                              errors={})
        except Exception, e:
            log.exception(e)
            c.failed_for = LOGBOOK_ENTRY_SHOW_FAILED
            c.failed_text = LOGBOOK_ENTRY_SHOW_FAILED_TEXT
            c.url_ok = url_for(controller='/logbook', action='index',
                               id=session['case'].id)
            return render('/logbook/dialogs/failed_show_logbook_entry.mako')

    @checkRole('cm_ka')
    def editAction(self):
        params = request.params
        id = self._checkInt(params.getone('id'))
        checker = LogbookEntryChecker(params, check_case_id=False)
        validator = EditLogbookForm()

        try:
            form_result = validator.to_python(params)
        except formencode.Invalid, error:
            c.form_result = error.value
            c.form_errors = error.error_dict or {}
            form = render('/logbook/new.mako')
            return formencode.htmlfill.render(form,
                                              defaults=c.form_result,
                                              auto_insert_errors=False,
                                              errors=c.form_errors)

        #if checker.hasErrors():
        #    c.errors = checker.getErrors()
        #    c.entry  = checker.getLogbookEntry()
        #    c.entry.setId(id)
        #    return render('/logbook/edit.mako')

        try:
            entry = checker.getLogbookEntry()
            entry.setId(id)
            entry.storeForUser(session['USER_AUTHORIZED'].id)

            c.success_for = LOGBOOK_ENTRY_SAVE_SUCCESS
            c.success_text = LOGBOOK_ENTRY_SAVE_SUCCESS_TEXT
            c.url_ok = url_for(controller='/logbook', action='index',
                               id=session['case'].id)
            return render('/logbook/dialogs/success_save_logbook_entry.mako')
        except Exception, e:
            log.exception(e)
            c.failed_for = LOGBOOK_ENTRY_SAVE_FAILED
            c.failed_text = LOGBOOK_ENTRY_SAVE_FAILED_TEXT
            c.url_ok = url_for(controller='/logbook', action='index',
                               id=session['case'].id)
            return render('/logbook/dialogs/failed_save_logbook_entry.mako')

    @checkRole('cm_ka')
    def delete(self, id, confirmed=False):
        id = self._checkInt(id)
        confirmed = self._checkBool(confirmed)
        if confirmed == 1:
            try:
                Logbook().deleteEntryById(int(id))
                c.success_for = LOGBOOK_ENTRY_DELETE_SUCCESS
                c.success_text = LOGBOOK_ENTRY_DELETE_SUCCESS_TEXT
                c.url_ok = url_for(controller='logbook', action='index',
                                   id=session['case'].id)
                return render('/logbook/dialogs/success_delete_logbook_entry.mako')
            except Exception, e:
                log.exception(e)
                c.failed_for = LOGBOOK_ENTRY_DELETE_FAILED
                c.failed_text = LOGBOOK_ENTRY_DELETE_FAILED_TEXT
                c.url_ok = url_for(controller='/logbook', action='index',
                                   id=session['case'].id)
                return render('/logbook/dialogs/failed_delete_logbook_entry.mako')
        else:
            c.confirm_for = DELETE_LOGBOOK_ENTRY_CONFIRM
            c.question = DELETE_LOGBOOK_ENTRY_CONFIRM_TEXT
            c.url_yes = url_for(controller='/logbook', action='delete', id=id,
                                confirmed=1)
            c.url_no = url_for(controller='/logbook', action='index',
                               id=session['case'].id)
            return render('/logbook/dialogs/confirm_delete_logbook_entry.mako')

    @checkRole(('cm_ka'))
    def printout(self, id):
        id = self._checkInt(id)
        c.print_version = 1
        
        # Load logbook
        logbook = Logbook()
        logbook.loadById(id)
        c.logbook = logbook
        
        # Load case
        case = self._loadCase(logbook.getMasterId())
        c.case = case
        
        return render('/logbook/overview_print.mako')
    
    

# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
