# -*- coding: utf-8 -*-
import logging

from pylons import c, g

from mpulsweb.lib.translation import _
from mpulsweb.lib.base import BaseController, h, render, request
from mpulsweb.lib.security import checkRole
from mpulsweb.model.phase import PhaseFactory, PC_FULLAUTO

log = logging.getLogger(__name__)

class PhaseController(BaseController):

    @checkRole(('admin_ka', 'cm_ka'))
    def index(self, id):
        return self.overview(id)

    @checkRole(('admin_ka', 'cm_ka'))
    def overview(self, id):
        id = self._checkInt(id)
        c.phases = PhaseFactory().load(id)
        # Only show buttons to set the phase if 
        c.show_actions = g.mpuls_config.get('phases', 'changemode') != PC_FULLAUTO 
        return render('/phase/phase.mako')

    @checkRole(('cm_ka'))
    def setPhase(self, id, value):

        SET_PHASE_NOTIFICATION_SUCCESS = _("Phase changed!")
        SET_PHASE_NOTIFICATION_TEXT_SUCCESS= _("The phase could be changed successfully. \
            Please follow the shown steps to reach the phase overview.")

        case = self._loadCase(id)
        # Set phase
        case.setPhase(value)

        # After setting the phase. Show print-dialog
        c.dialog_title = SET_PHASE_NOTIFICATION_SUCCESS
        c.dialog_text = SET_PHASE_NOTIFICATION_TEXT_SUCCESS
        c.url_ok = h.url_for(controller='/phase', action='overview', id=case.id)
        return render('/phase/dialogs/success_set_phase.mako')

    @checkRole(('cm_ka'))
    def editAction(self):
        case = self._loadCase(request.params.get('case_id'))
        newphase = None

        # TODO: This is ugly. The id of the phase to be set is submitted as key
        # (intvalue)) of the submitbutton. So to find the right value, try to
        # convert all keys to int, which should only work for the
        # submitbuttons.
        for newphase in request.params.iterkeys():
            try:
                newphase = int(newphase)
                break
            except:
                pass # convert failed, seems not to be the submit button.
                     # Continue...
        return self.setPhase(request.params.get('case_id'), newphase)
