#!/bin/bash
#
# waska_recover_case.sh
# Frank Koormann <frank.koormann@intevation.de>
#
# Get WASKA case record from table based dumps
#
# Usage: waska_recover_case.sh <db> <master-id>
#
# Expected naming scheme:
#	<pattern>_master_tbl.dump
#	<pattern>_rg_kompetenz_tbl.dump
#	<pattern>_rg_bb_tbl.dump
#	<pattern>_rg_bq_tbl.dump
#	<pattern>_rg_bv_tbl.dump
#	<pattern>_rg_lb_tbl.dump
#
# Dumps are based on this command:
# pg_dump -aODx -t $table <db> -p 5440 > <db>_$table_dump
#
# Concept: Find record's initial row in dump file. Read from that line until
# 		end of record.

db=$1
mid=$2
# delete entry before inserting
echo "DELETE FROM master_tbl WHERE id = $2;"


# master table:
pattern=`echo \(${mid}$`
row=`cut -f 222 -d, ${db}_master_tbl.dump | nl -ba -nln | grep ${pattern} | cut -f1`

for i in $row
do
    tail -n +${i} ${db}_master_tbl.dump | until [[ "$line" =~ "');$" ]]; do read line; echo $line; done;
done

# Einverstaendniserklaerung auf unbekannt
echo "UPDATE master_tbl SET einverstaendniserklaerung = -1 WHERE id = ${2};"

# KA Status Table (sichtbar (offen))
echo "INSERT INTO ka_status_tbl (master_id, status, zugriff) VALUES (${2}, 1, now());"

# kompetenzfeststellung
pattern=`echo [[:space:]]${mid}$`
row=`cut -f 76 -d, ${db}_rg_kompetenz_tbl.dump | nl -ba -nln | grep ${pattern} | cut -f1`

for i in $row
do
    tail -n +${i} ${db}_rg_kompetenz_tbl.dump | until [[ "$line" =~ "');$" ]]; do read line; echo $line; done;
done

# rg_bb
#	<pattern>_rg_bb_tbl.dump
pattern=`echo [[:space:]]${mid}$`
row=`cut -f 16 -d, ${db}_rg_bb_tbl.dump | nl -ba -nln | grep ${pattern} | cut -f1`

for i in $row
do
    tail -n +${i} ${db}_rg_bb_tbl.dump | until [[ "$line" =~ "');$" ]]; do read line; echo $line; done;
done

# rg_bq
#	<pattern>_rg_bq_tbl.dump
pattern=`echo [[:space:]]${mid}$`
row=`cut -f 16,17 -d, ${db}_rg_bq_tbl.dump | nl -ba -nln | grep ${pattern} | cut -f1`

for i in $row
do
    tail -n +${i} ${db}_rg_bq_tbl.dump | until [[ "$line" =~ "');$" ]]; do read line; echo $line; done;
done

# rg_bv
#	<pattern>_rg_bv_tbl.dump
pattern=`echo [[:space:]]${mid}$`
row=`cut -f 16,17 -d, ${db}_rg_bv_tbl.dump | nl -ba -nln | grep ${pattern} | cut -f1`

for i in $row
do
    tail -n +${i} ${db}_rg_bv_tbl.dump | until [[ "$line" =~ "');$" ]]; do read line; echo $line; done;
done

# rg_lb
#	<pattern>_rg_lb_tbl.dump
pattern=`echo [[:space:]]${mid}$`
row=`cut -f 17,18 -d, ${db}_rg_lb_tbl.dump | nl -ba -nln | grep ${pattern} | cut -f1`

for i in $row
do
    tail -n +${i} ${db}_rg_lb_tbl.dump | until [[ "$line" =~ "');$" ]]; do read line; echo $line; done;
done

