--
-- Aktiverung des Logging für WASKA
--
-- Protokolliert werden:
-- - Zeitstempel (über DB Konfiguration, vgl. log_line_prefix)
-- - Datenbank (über DB Konfiguration, vgl. log_line_prefix)
-- - ID des Datensatz
-- - Aktion
-- - Tabelle
-- - User
--
-- Nicht protokolliert werden die genauen Eingaben. Diese lassen sich bei
-- Bedarf aus dem Write-Ahead-Log rekonstruieren, nachdem in den
-- Protokolldateien der Zeitpunkt identifiziert wurde.

BEGIN;

CREATE OR REPLACE FUNCTION mpuls_log() RETURNS TRIGGER AS $$
BEGIN
    IF TG_OP = 'DELETE' THEN
        RAISE LOG '% on % (id: %) by %', TG_OP, TG_TABLE_NAME, OLD.id, session_user;
        RETURN OLD;
    ELSE
        RAISE LOG '% on % (id: %) by %', TG_OP, TG_TABLE_NAME, NEW.id, session_user;
        RETURN NEW;
    END IF;
END;
$$ LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION mpuls_tag() RETURNS TRIGGER AS $$
BEGIN
    IF TG_OP = 'DELETE' THEN
        RETURN OLD;
    ELSE
    	PERFORM check_case(NEW.id);
        RETURN NEW;
    END IF;
END;
$$ LANGUAGE plpgsql;


-- master_tbl
CREATE TRIGGER t_master_tbl_insert AFTER
    INSERT ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log(); 

CREATE TRIGGER t_master_tbl_update AFTER
    UPDATE ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_master_tbl_insert_check AFTER
    INSERT ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_tag(); 

CREATE TRIGGER t_master_tbl_update_check AFTER
    UPDATE ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_tag();

CREATE TRIGGER t_master_tbl_delete AFTER
    DELETE ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

-- rg_kompetenzfestellung_tbl
-- CREATE TRIGGER t_rg_kompetenzfestellung_tbl_insert AFTER
--     INSERT ON rg_kompetenzfestellung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_kompetenzfestellung_tbl_update AFTER
--     UPDATE ON rg_kompetenzfestellung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_kompetenzfestellung_tbl_delete AFTER
--     DELETE ON rg_kompetenzfestellung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- -- rg_angebote_bildenden_bereich_tbl
-- CREATE TRIGGER t_rg_angebote_bildenden_bereich_tbl_insert AFTER
--     INSERT ON rg_angebote_bildenden_bereich_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_angebote_bildenden_bereich_tbl_update AFTER
--     UPDATE ON rg_angebote_bildenden_bereich_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_angebote_bildenden_bereich_tbl_delete AFTER
--     DELETE ON rg_angebote_bildenden_bereich_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- -- rg_angebote_berufsvorbereitung_tbl
-- CREATE TRIGGER t_rg_angebote_berufsvorbereitung_tbl_insert AFTER
--     INSERT ON rg_angebote_berufsvorbereitung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_angebote_berufsvorbereitung_tbl_update AFTER
--     UPDATE ON rg_angebote_berufsvorbereitung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_angebote_berufsvorbereitung_tbl_delete AFTER
--     DELETE ON rg_angebote_berufsvorbereitung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- -- rg_angebote_berufliche_qualifizierung_tbl
-- CREATE TRIGGER t_rg_angebote_berufliche_qualifizierung_tbl_insert AFTER
--     INSERT ON rg_angebote_berufliche_qualifizierung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_angebote_berufliche_qualifizierung_tbl_update AFTER
--     UPDATE ON rg_angebote_berufliche_qualifizierung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_angebote_berufliche_qualifizierung_tbl_delete AFTER
--     DELETE ON rg_angebote_berufliche_qualifizierung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- -- rg_angebote_lebensbewaeltigung_tbl
-- CREATE TRIGGER t_rg_angebote_lebensbewaeltigung_tbl_insert AFTER
--     INSERT ON rg_angebote_lebensbewaeltigung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_angebote_lebensbewaeltigung_tbl_update AFTER
--     UPDATE ON rg_angebote_lebensbewaeltigung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();
-- 
-- CREATE TRIGGER t_rg_angebote_lebensbewaeltigung_tbl_delete AFTER
--     DELETE ON rg_angebote_lebensbewaeltigung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

-- ka_benutzer_tbl
CREATE TRIGGER t_ka_benutzer_tbl_insert AFTER
    INSERT ON ka_benutzer_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_benutzer_tbl_update AFTER
    UPDATE ON ka_benutzer_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_benutzer_tbl_delete AFTER
    DELETE ON ka_benutzer_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

-- ka_konfiguration_tbl
CREATE TRIGGER t_ka_konfiguration_tbl_insert AFTER
    INSERT ON ka_konfiguration_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_konfiguration_tbl_update AFTER
    UPDATE ON ka_konfiguration_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_konfiguration_tbl_delete AFTER
    DELETE ON ka_konfiguration_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

-- ka_dokumente_tbl
CREATE TRIGGER t_ka_dokumente_tbl_insert AFTER
    INSERT ON ka_dokumente_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_dokumente_tbl_update AFTER
    UPDATE ON ka_dokumente_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_dokumente_tbl_delete AFTER
    DELETE ON ka_dokumente_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

-- ka_termine_tbl
CREATE TRIGGER t_ka_termine_tbl_insert AFTER
    INSERT ON ka_termine_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_termine_tbl_update AFTER
    UPDATE ON ka_termine_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_termine_tbl_delete AFTER
    DELETE ON ka_termine_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

-- ka_logbuch_tbl
CREATE TRIGGER t_ka_logbuch_tbl_insert AFTER
    INSERT ON ka_logbuch_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_logbuch_tbl_update AFTER
    UPDATE ON ka_logbuch_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();

CREATE TRIGGER t_ka_logbuch_tbl_delete AFTER
    DELETE ON ka_logbuch_tbl
    FOR EACH ROW EXECUTE PROCEDURE mpuls_log();


--
-- Automatisches Setzen eines Zeitstempels in der ka_status_tbl
-- Diese Trigger sorgen dafür, dass bei jeder Bearbeitung der Fallakten der
-- Zeitpunkt der Bearbeitung gespeichert wird.
--
CREATE OR REPLACE FUNCTION set_lastaccess_time( masterid integer ) 
RETURNS void AS 
$$
BEGIN
    UPDATE ka_status_tbl_view set zugriff = now() WHERE master_id = masterid;  
END;
$$ LANGUAGE plpgsql VOLATILE;

CREATE OR REPLACE FUNCTION master_lastaccess_log() RETURNS trigger AS $master_lastaccess_log$
BEGIN
    EXECUTE set_lastaccess_time(NEW.id);
    RETURN NEW;
END;
$master_lastaccess_log$ LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION status_lastaccess_log() RETURNS trigger AS $status_lastaccess_log$
BEGIN
IF NEW.status <> OLD.status AND OLD.zugriff IS NOT NULL THEN
    EXECUTE set_lastaccess_time(NEW.master_id);
END IF;
RETURN NEW;
END;
$status_lastaccess_log$ LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION rg_lastaccess_log() RETURNS trigger AS $rg_lastaccess_log$
BEGIN
IF TG_OP = 'DELETE' THEN
    EXECUTE set_lastaccess_time(OLD.master_id);
    RETURN OLD;
ELSE
    EXECUTE set_lastaccess_time(NEW.master_id);
    RETURN NEW;
END IF;
END;
$rg_lastaccess_log$ LANGUAGE plpgsql;

CREATE TRIGGER t1_master_tbl_update AFTER
    UPDATE ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE master_lastaccess_log();

-- rg_kompetenzfestellung_tbl
-- CREATE TRIGGER t1_rg_kompetenzfestellung_tbl_insert AFTER
--     INSERT ON rg_kompetenzfestellung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_kompetenzfestellung_tbl_update AFTER
--     UPDATE ON rg_kompetenzfestellung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_kompetenzfestellung_tbl_delete AFTER
--     DELETE ON rg_kompetenzfestellung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- -- rg_angebote_bildenden_bereich_tbl
-- CREATE TRIGGER t1_rg_angebote_bildenden_bereich_tbl_insert AFTER
--     INSERT ON rg_angebote_bildenden_bereich_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_angebote_bildenden_bereich_tbl_update AFTER
--     UPDATE ON rg_angebote_bildenden_bereich_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_angebote_bildenden_bereich_tbl_delete AFTER
--     DELETE ON rg_angebote_bildenden_bereich_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- -- rg_angebote_berufsvorbereitung_tbl
-- CREATE TRIGGER t1_rg_angebote_berufsvorbereitung_tbl_insert AFTER
--     INSERT ON rg_angebote_berufsvorbereitung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_angebote_berufsvorbereitung_tbl_update AFTER
--     UPDATE ON rg_angebote_berufsvorbereitung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_angebote_berufsvorbereitung_tbl_delete AFTER
--     DELETE ON rg_angebote_berufsvorbereitung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- -- rg_angebote_berufliche_qualifizierung_tbl
-- CREATE TRIGGER t1_rg_angebote_berufliche_qualifizierung_tbl_insert AFTER
--     INSERT ON rg_angebote_berufliche_qualifizierung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_angebote_berufliche_qualifizierung_tbl_update AFTER
--     UPDATE ON rg_angebote_berufliche_qualifizierung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_angebote_berufliche_qualifizierung_tbl_delete AFTER
--     DELETE ON rg_angebote_berufliche_qualifizierung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- -- rg_angebote_lebensbewaeltigung_tbl
-- CREATE TRIGGER t1_rg_angebote_lebensbewaeltigung_tbl_insert AFTER
--     INSERT ON rg_angebote_lebensbewaeltigung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_angebote_lebensbewaeltigung_tbl_update AFTER
--     UPDATE ON rg_angebote_lebensbewaeltigung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_rg_angebote_lebensbewaeltigung_tbl_delete AFTER
--     DELETE ON rg_angebote_lebensbewaeltigung_tbl
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

-- ka_termine_tbl
CREATE TRIGGER t1_ka_termine_tbl_insert AFTER
    INSERT ON ka_termine_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_ka_termine_tbl_update AFTER
    UPDATE ON ka_termine_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_ka_termine_tbl_delete AFTER
    DELETE ON ka_termine_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

-- ka_dokumente_tbl
CREATE TRIGGER t1_ka_dokumente_tbl_insert AFTER
    INSERT ON ka_dokumente_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_ka_dokumente_tbl_update AFTER
    UPDATE ON ka_dokumente_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_ka_dokumente_tbl_delete AFTER
    DELETE ON ka_dokumente_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

-- ka_logbuch_tbl
CREATE TRIGGER t1_ka_logbuch_tbl_insert AFTER
    INSERT ON ka_logbuch_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_ka_logbuch_tbl_update AFTER
    UPDATE ON ka_logbuch_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_ka_logbuch_tbl_delete AFTER
    DELETE ON ka_logbuch_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

-- nm_benutzer_master_tbl
CREATE TRIGGER t1_nm_benutzer_master_tbl_insert AFTER
    INSERT ON nm_benutzer_master_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_nm_benutzer_master_tbl_update AFTER
    UPDATE ON nm_benutzer_master_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_nm_benutzer_master_tbl_delete AFTER
    DELETE ON nm_benutzer_master_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

-- ka_status_tbl
CREATE TRIGGER t1_ka_status_tbl_update AFTER
    UPDATE ON ka_status_tbl
    FOR EACH ROW EXECUTE PROCEDURE status_lastaccess_log();

-- tags
-- CREATE TRIGGER t1_nm_tags_cases_insert AFTER
--     INSERT ON nm_tags_cases
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_nm_tags_cases_update AFTER
--     UPDATE ON nm_tags_cases
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();
-- 
-- CREATE TRIGGER t1_nm_tags_cases_delete AFTER
--     DELETE ON nm_tags_cases
--     FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

-- Trigger fuer das automatische Anlegen eines Logbucheintrages
-- beim Anlegen eines Masterdatensatzes.

CREATE OR REPLACE FUNCTION master_ds_created_logbook() RETURNS trigger AS $master_ds_created_logbook$
DECLARE
    lid integer;
BEGIN
    SELECT INTO lid create_logbuch_ds(NEW.id, NULL);
    UPDATE ka_logbuch_tbl_view
        SET art = 0, notiz = 'Fallakte angelegt.'
    WHERE
        id = lid;
    RETURN NEW;
END;
$master_ds_created_logbook$ LANGUAGE plpgsql;

CREATE TRIGGER master_ds_created_logbook_trigger AFTER
    INSERT ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE master_ds_created_logbook();

--
-- Trigger, der nach Uebertragung der Fallakte an einen anderen
-- Bearbeiter den alten und neuen Bearbeiter eintraegt in das Logbuch eintraegt.
--
CREATE OR REPLACE FUNCTION master_ds_editor_changed() RETURNS trigger AS $master_ds_editor_changed$
DECLARE
    lid      integer;
    old_user RECORD;
    new_user RECORD;
BEGIN
    IF OLD.bearbeiter_id <> NEW.bearbeiter_id THEN

        SELECT INTO old_user * FROM ka_benutzer_tbl WHERE id = OLD.bearbeiter_id;
        SELECT INTO new_user * FROM ka_benutzer_tbl WHERE id = NEW.bearbeiter_id;

        SELECT INTO lid create_logbuch_ds(NEW.id, NULL);

        UPDATE ka_logbuch_tbl_view
            SET art = 0, 
            notiz = 'Fallakte übertragen von ' 
                    || coalesce(old_user.nachname, '-/-') || ', '
                    || coalesce(old_user.vorname,  '-/-') || ' an '
                    || coalesce(new_user.nachname, '-/-') || ', '
                    || coalesce(new_user.vorname,  '-/-')
        WHERE
            id = lid;
    END IF;
    RETURN NEW;
END;
$master_ds_editor_changed$ LANGUAGE plpgsql;

CREATE TRIGGER master_ds_editor_changed_trigger AFTER
    UPDATE ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE master_ds_editor_changed();
