BEGIN;

-- 
-- Neue Option bei der Angabe des Familieneinkommens.
--

SET ROLE :db_adm;

ALTER TABLE master_tbl ADD COLUMN einkommen_e INTEGER DEFAULT -1;
ALTER TABLE master_tbl ADD FOREIGN KEY (einkommen_e) REFERENCES einkommen_a_tbl (id);

DROP VIEW page_6_view cascade;
CREATE OR REPLACE VIEW page_6_view AS SELECT
    master_tbl.id AS id,
    master_tbl.einkommen_a AS einkommen_a,
    master_tbl.einkommen_b AS einkommen_b,
    master_tbl.einkommen_c AS einkommen_c,
    master_tbl.einkommen_e AS einkommen_e,
    master_tbl.einkommen_d AS einkommen_d,
    master_tbl.einkommen_d_t AS einkommen_d_t
FROM master_tbl
WHERE
    master_tbl.bearbeiter_id = getuserid()
    OR master_tbl.id IN (
        SELECT nm.master_id from nm_benutzer_master_tbl nm
        WHERE nm.benutzer_id IN (
            SELECT nm2.gruppe_id from nm_benutzer_gruppe_tbl nm2 
            WHERE nm2.benutzer_id = getuserid()
        )
    )
    OR pg_has_role('admin','MEMBER');

CREATE OR REPLACE RULE page_6_update_rule AS ON UPDATE TO page_6_view
DO INSTEAD UPDATE master_tbl SET
    einkommen_a = NEW.einkommen_a,
    einkommen_b = NEW.einkommen_b,
    einkommen_c = NEW.einkommen_c,
    einkommen_e = NEW.einkommen_e,
    einkommen_d = NEW.einkommen_d,
    einkommen_d_t = NEW.einkommen_d_t
WHERE id = NEW.id;

GRANT SELECT ON page_6_view TO GROUP :cm_group;
GRANT UPDATE ON page_6_view TO GROUP :cm_group;
GRANT SELECT ON page_6_view TO GROUP :admin_group;

CREATE OR REPLACE RULE page_6_delete_rule AS ON DELETE TO page_6_view
    DO INSTEAD NOTHING;

CREATE OR REPLACE RULE page_6_insert_rule AS ON INSERT TO page_6_view
    DO INSTEAD NOTHING;

DROP VIEW master_tbl_view cascade;
CREATE OR REPLACE VIEW master_tbl_view
AS SELECT master_tbl.* FROM master_tbl
WHERE
    master_tbl.bearbeiter_id = getuserid()
    OR master_tbl.id IN (
        SELECT nm.master_id from nm_benutzer_master_tbl nm
        WHERE nm.benutzer_id IN (
            SELECT nm2.gruppe_id from nm_benutzer_gruppe_tbl nm2 
            WHERE nm2.benutzer_id = getuserid()
        )
    )
    OR pg_has_role('admin','MEMBER');

CREATE OR REPLACE RULE master_tbl_delete_rule AS ON DELETE TO master_tbl_view
    DO INSTEAD NOTHING;

CREATE OR REPLACE RULE master_tbl_insert_rule AS ON INSERT TO master_tbl_view
    DO INSTEAD NOTHING;

GRANT SELECT ON master_tbl_view TO GROUP :cm_group;
GRANT UPDATE ON master_tbl_view TO GROUP :cm_group;
GRANT SELECT ON master_tbl_view TO GROUP :admin_group;

CREATE OR REPLACE VIEW master_tbl_anonym_view
AS SELECT
    id,
    uuid_id,
    bearbeiter_id,
    einwilligung,
    phase,
    fkz,
    ks,
    NULL::VARCHAR(256) AS fn,
    NULL::VARCHAR(256) AS mitarb_zv,
    hash_value(mitarb_zn, mitarb_zv) AS mitarb_zn,
    NULL::VARCHAR(256) AS mitarb_vv,
    NULL::VARCHAR(256) AS mitarb_vn,
    NULL::VARCHAR(256) AS name,
    NULL::VARCHAR(256) AS vorname,
    geschlecht,
    get_age(geburtsdatum) AS geburtsdatum,
    kontakt,
    erstgespraech,
    zugang,
    NULL::VARCHAR(256) AS zugang_t,
    cm2c,
    cm_dok_datum_beendigung,
    cm_dok_end_art,
    cm_dok_end_verm,
    cm_dok_end_sonst,
    cm_neuauf_genehm,
    cm_wiederauf_genehm_1,
    cm_wiederauf_genehm_datum_1,
    cm_wiederauf_datum_bis_1,
    cm_wiederauf_genehm_2,
    cm_wiederauf_datum_bis_2,
    NULL::TEXT AS cm2c_t,
    NULL::VARCHAR(256) AS kd_schule_name_1,
    NULL::VARCHAR(256) AS kd_schule_strasse_1,
    NULL::VARCHAR(256) AS kd_schule_strassenr_1,
    NULL::VARCHAR(256) AS kd_schule_plz_1,
    NULL::VARCHAR(256) AS kd_schule_ort_1,
    NULL::VARCHAR(256) AS kd_schule_vorwahl_1,
    NULL::VARCHAR(256) AS kd_schule_telefonnummer_1,
    NULL::VARCHAR(256) AS kd_schule_email_1,
    NULL::VARCHAR(256) AS bezugs_name_1,
    NULL::VARCHAR(256) AS bezugs_vorname_1,
    NULL::VARCHAR(256) AS bezugs_vorwahl_1,
    NULL::VARCHAR(256) AS bezugs_telefonnummer_1,
    NULL::VARCHAR(256) AS bezugs_email_1,
    NULL::VARCHAR(256) AS kd_jugendamt_kundennummer_1,
    NULL::VARCHAR(256) AS kd_jugendamt_strasse_1,
    NULL::VARCHAR(256) AS kd_jugendamt_strassenr_1,
    NULL::VARCHAR(256) AS kd_jugendamt_plz_1,
    NULL::VARCHAR(256) AS kd_jugendamt_ort_1,
    NULL::VARCHAR(256) AS kd_jugendamt_vorwahl_1,
    NULL::VARCHAR(256) AS kd_jugendamt_telefonnummer_1,
    NULL::VARCHAR(256) AS kd_jugendamt_email_1,
    NULL::VARCHAR(256) AS kd_institution_name_1,
    NULL::VARCHAR(256) AS kd_institution_kundennummer_1,
    NULL::VARCHAR(256) AS kd_institution_strasse_1,
    NULL::VARCHAR(256) AS kd_institution_strassenr_1,
    NULL::VARCHAR(256) AS kd_institution_plz_1,
    NULL::VARCHAR(256) AS kd_institution_ort_1,
    NULL::VARCHAR(256) AS kd_institution_vorwahl_1,
    NULL::VARCHAR(256) AS kd_institution_telefonnummer_1,
    NULL::VARCHAR(256) AS kd_institution_email_1,
    NULL::VARCHAR(256) AS kd_institution_name_2,
    NULL::VARCHAR(256) AS kd_institution_kundennummer_2,
    NULL::VARCHAR(256) AS kd_institution_strasse_2,
    NULL::VARCHAR(256) AS kd_institution_strassenr_2,
    NULL::VARCHAR(256) AS kd_institution_plz_2,
    NULL::VARCHAR(256) AS kd_institution_ort_2,
    NULL::VARCHAR(256) AS kd_institution_vorwahl_2,
    NULL::VARCHAR(256) AS kd_institution_telefonnummer_2,
    NULL::VARCHAR(256) AS kd_institution_email_2,
    NULL::VARCHAR(256) AS kd_institution_name_3,
    NULL::VARCHAR(256) AS kd_institution_kundennummer_3,
    NULL::VARCHAR(256) AS kd_institution_strasse_3,
    NULL::VARCHAR(256) AS kd_institution_strassenr_3,
    NULL::VARCHAR(256) AS kd_institution_plz_3,
    NULL::VARCHAR(256) AS kd_institution_ort_3,
    NULL::VARCHAR(256) AS kd_institution_vorwahl_3,
    NULL::VARCHAR(256) AS kd_institution_telefonnummer_3,
    NULL::VARCHAR(256) AS kd_institution_email_3,
    NULL::TEXT AS dok_eingang,
    datum_cm_start,
    NULL::VARCHAR(256) AS addresse_strasse_1,
    NULL::VARCHAR(256) AS addresse_strassenr_1,
    shorten_value(addresse_plz_1, 3) AS addresse_plz_1,
    NULL::VARCHAR(256) AS addresse_ort_1,
    NULL::VARCHAR(256) AS addresse1_vorwahl_1,
    NULL::VARCHAR(256) AS addresse1_telefonnummer_1,
    NULL::VARCHAR(256) AS addresse2_vorwahl_1,
    NULL::VARCHAR(256) AS addresse2_telefonnummer_2,
    NULL::VARCHAR(256) AS addresse_weiteretelefonnummern_1,
    NULL::VARCHAR(256) AS addresse_email_1,
    wohnort,
    wohnauf,
    NULL::VARCHAR(256) AS wohnauf_t,
    kinder,
    kinder_hh,
    kinder_allein,
    nat_land,
    NULL::VARCHAR(256) AS nat_land_t,
    nat_staat,
    nat_status,
    nat_wohn,
    nat_muspra,
    NULL::VARCHAR(256) AS nat_muspra_t,
    nat_haspra,
    psorge,
    NULL::VARCHAR(256) AS psorge_t,
    mutter,
    NULL::VARCHAR(256) AS mutter_n,
    NULL::VARCHAR(256) AS mutter_vn,
    NULL::DATE AS mutter_gb,
    NULL::VARCHAR(256) AS mutter_strasse_1,
    NULL::VARCHAR(256) AS mutter_strassenr_1,
    NULL::VARCHAR(256) AS mutter_plz_1,
    NULL::VARCHAR(256) AS mutter_ort_1,
    NULL::VARCHAR(256) AS mutter_vorwahl1_1,
    NULL::VARCHAR(256) AS mutter_telefonnummer1_1,
    NULL::VARCHAR(256) AS mutter_vorwahl2_1,
    NULL::VARCHAR(256) AS mutter_telefonnummer2_1,
    NULL::VARCHAR(256) AS mutter_email_1,
    mutter_land,
    NULL::VARCHAR(256) AS mutter_land_t,
    mutter_staat,
    mutter_spra,
    mutter_bildung,
    NULL::VARCHAR(256) AS mutter_bildung_t,
    mutter_beruf,
    NULL::TEXT AS mutter_sonst,
    vater,
    NULL::VARCHAR(256) AS vater_n,
    NULL::VARCHAR(256) AS vater_vn,
    NULL::DATE AS vater_gb,
    NULL::VARCHAR(256) AS vater_strasse_1,
    NULL::VARCHAR(256) AS vater_strassenr_1,
    NULL::VARCHAR(256) AS vater_plz_1,
    NULL::VARCHAR(256) AS vater_ort_1,
    NULL::VARCHAR(256) AS vater_vorwahl1_1,
    NULL::VARCHAR(256) AS vater_telefonnummer1_1,
    NULL::VARCHAR(256) AS vater_vorwahl2_1,
    NULL::VARCHAR(256) AS vater_telefonnummer2_1,
    NULL::VARCHAR(256) AS vater_email_1,
    vater_land,
    NULL::VARCHAR(256) AS vater_land_t,
    vater_staat,
    vater_spra,
    vater_bildung,
    NULL::VARCHAR(256) AS vater_bildung_t,
    vater_beruf,
    NULL::TEXT AS vater_sonst,
    geschw_vorhanden,
    geschw_w,
    geschw_m,
    geschw_hh,
    geschw_alt_a,
    geschw_alt_b,
    geschw_alt_c,
    geschw_alt_d,
    einkommen_a,
    einkommen_b,
    einkommen_c,
    einkommen_e,
    einkommen_d,
    NULL::TEXT AS einkommen_d_t,
    bezugsperson_a,
    bezugsperson_b,
    bezugsperson_c,
    bezugsperson_d,
    bezugsperson_e,
    bezugsperson_f,
    bezugsperson_g,
    bezugsperson_h,
    bezugsperson_i,
    bezugsperson_j,
    bezugsperson_k,
    bezugsperson_l,
    bezugsperson_m,
    bezugsperson_n,
    bezugsperson_o,
    bezugsperson_p,
    bezugsperson_q,
    bezugsperson_r,
    NULL::VARCHAR(256) AS bezugsperson_r_t,
    NULL::VARCHAR(256) AS kd_bezug_name_1,
    NULL::VARCHAR(256) AS kd_bezug_vorname_1,
    NULL::INTEGER AS kd_bezug_funktion_1,
    NULL::VARCHAR(256) AS kd_bezug_strasse_1,
    NULL::VARCHAR(256) AS kd_bezug_strassenr_1,
    NULL::VARCHAR(256) AS kd_bezug_plz_1,
    NULL::VARCHAR(256) AS kd_bezug_ort_1,
    NULL::VARCHAR(256) AS kd_bezug_1_vorwahl,
    NULL::VARCHAR(256) AS kd_bezug_1_telefon,
    NULL::VARCHAR(256) AS kd_bezug_email_1,
    NULL::VARCHAR(256) AS kd_bezug_name_2,
    NULL::VARCHAR(256) AS kd_bezug_vorname_2,
    NULL::INTEGER AS kd_bezug_funktion_2,
    NULL::VARCHAR(256) AS kd_bezug_strasse_2,
    NULL::VARCHAR(256) AS kd_bezug_strassenr_2,
    NULL::VARCHAR(256) AS kd_bezug_plz_2,
    NULL::VARCHAR(256) AS kd_bezug_ort_2,
    NULL::VARCHAR(256) AS kd_bezug_2_vorwahl,
    NULL::VARCHAR(256) AS kd_bezug_2_telefon,
    NULL::VARCHAR(256) AS kd_bezug_email_2,
    NULL::VARCHAR(256) AS kd_bezug_name_3,
    NULL::VARCHAR(256) AS kd_bezug_vorname_3,
    NULL::INTEGER AS kd_bezug_funktion_3,
    NULL::VARCHAR(256) AS kd_bezug_strasse_3,
    NULL::VARCHAR(256) AS kd_bezug_strassenr_3,
    NULL::VARCHAR(256) AS kd_bezug_plz_3,
    NULL::VARCHAR(256) AS kd_bezug_ort_3,
    NULL::VARCHAR(256) AS kd_bezug_3_vorwahl,
    NULL::VARCHAR(256) AS kd_bezug_3_telefon,
    NULL::VARCHAR(256) AS kd_bezug_email_3,
    zugeh_a,
    zugeh_b,
    zugeh_c,
    zugeh_d,
    NULL::TEXT AS dok_angaben,
    schulform,
    NULL::VARCHAR(256) AS schulform_t,
    klassenstufe,
    klassenwdh,
    sinteresse_a,
    sinteresse_b,
    leistung_ges,
    leistung_d,
    leistung_m,
    leistung_fs,
    sv_aktiv,
    sv_passiv,
    sv_a,
    sv_b,
    sv_c,
    sv_d,
    sv_e,
    sv_f,
    sv_g,
    NULL::VARCHAR(256) AS sv_g_t,
    fehltg_sj,
    fehltg_sj_ue,
    fehltg_m,
    fehltg_m_ue,
    fehlst_sj,
    fehlst_sj_ue,
    fehlst_m,
    fehlst_m_ue,
    sv_monate,
    abschl_gef,
    abschl_pr,
    ordmn,
    ekomp_a,
    ekomp_b,
    ekomp_c,
    ekomp_d,
    ekomp_e,
    ekomp_f,
    ekomp_g,
    ekomp_h,
    ekomp_i,
    NULL::VARCHAR(256) AS ekomp_i_t,
    problfam_a,
    problfam_b,
    problfam_c,
    problfam_d,
    problfam_e,
    problfam_f,
    problfam_g,
    problfam_h,
    problfam_i,
    problfam_j,
    problfam_k,
    problfam_l,
    problfam_m,
    NULL::VARCHAR(256) AS problfam_m_t,
    NULL::TEXT AS familie_anm,
    uleistung_beginn,
    uleistung_beginn_a,
    uleistung_beginn_b,
    uleistung_beginn_c,
    uleistung_beginn_d,
    uleistung_beginn_e,
    uleistung_beginn_f,
    uleistung_beginn_g,
    uleistung_beginn_h,
    uleistung_beginn_i,
    uleistung_beginn_j,
    NULL::VARCHAR(256) AS uleistung_beginn_j_t,
    uleistung_verg,
    NULL::TEXT AS uleistung_anm,
    NULL::TEXT AS dok_biograf,
    datum_kf_1,
    kf_verfahren_1,
    kf_anbiet_1,
    kf_meth_a_1,
    kf_meth_b_1,
    kf_meth_d_1,
    kf_meth_e_1,
    kf_meth_f_1,
    NULL::VARCHAR(256) AS kf_meth_f_t_1,
    kf_test_a_1,
    kf_test_a_t_1,
    kf_test_b_1,
    kf_test_b_t_1,
    kf_test_c_1,
    kf_test_c_t_1,
    kf_test_d_1,
    kf_test_d_t_1,
    komp_schule_a_1,
    komp_schule_b_1,
    komp_schule_c_1,
    komp_schule_d_1,
    komp_schule_e_1,
    komp_schule_f_1,
    komp_schule_g_1,
    NULL::VARCHAR(256) AS komp_schule_g_t_1,
    komp_deutsch_a_1,
    komp_deutsch_b_1,
    komp_deutsch_c_1,
    komp_deutsch_d_1,
    komp_herkunft_1,
    komp_sozial_a_1,
    komp_sozial_b_1,
    komp_sozial_c_1,
    komp_sozial_d_1,
    komp_sozial_e_1,
    komp_sozial_f_1,
    komp_sozial_g_1,
    NULL::VARCHAR(256) AS komp_sozial_g_t_1,
    komp_selbst_a_1,
    komp_selbst_b_1,
    komp_selbst_c_1,
    komp_selbst_d_1,
    komp_selbst_e_1,
    komp_selbst_f_1,
    komp_selbst_g_1,
    NULL::VARCHAR(256) AS komp_selbst_g_t_1,
    komp_psy_a_1,
    komp_psy_b_1,
    komp_psy_c_1,
    komp_psy_d_1,
    komp_psy_e_1,
    komp_psy_f_1,
    komp_psy_g_1,
    komp_psy_g_t_1,
    NULL::TEXT AS komp_anm,
    entw_a_1,
    entw_b_1,
    entw_c_1,
    entw_d_1,
    entw_e_1,
    entw_f_1,
    entw_g_1,
    entw_h_1,
    NULL::VARCHAR(256) AS entw_h_t_1,
    entw_i_1,
    NULL::VARCHAR(256) AS entw_i_t_1,
    entw_j_1,
    NULL::VARCHAR(256) AS entw_j_t_1,
    entw_k_1,
    NULL::VARCHAR(256) AS entw_k_t_1,
    entw_beh,
    NULL::TEXT AS dok_entw,
    datum_bfplan,
    beschul_a,
    beschul_b,
    beschul_c,
    beschul_d,
    beschul_e,
    beschul_f,
    beschul_h,
    NULL::VARCHAR(256) AS beschul_h_t,
    reint_ziel,
    NULL::VARCHAR(256) AS reint_ziel_t,
    NULL::TEXT AS reint_beding_a,
    NULL::TEXT AS reint_beding_b,
    NULL::TEXT AS reint_beding_c,
    NULL::VARCHAR(256) AS reint_beding_d_t,
    NULL::TEXT AS reint_beding_d,
    fehlm_1,
    fehlj_1,
    fehltg_1,
    fehlutg_1,
    fehlst_1,
    fehlfust_1,
    fehlm_2,
    fehlj_2,
    fehltg_2,
    fehlutg_2,
    fehlst_2,
    fehlfust_2,
    fehlm_3,
    fehlj_3,
    fehltg_3,
    fehlutg_3,
    fehlst_3,
    fehlfust_3,
    fehlm_4,
    fehlj_4,
    fehltg_4,
    fehlutg_4,
    fehlst_4,
    fehlfust_4,
    fehlm_5,
    fehlj_5,
    fehltg_5,
    fehlutg_5,
    fehlst_5,
    fehlfust_5,
    fehlm_6,
    fehlj_6,
    fehltg_6,
    fehlutg_6,
    fehlst_6,
    fehlfust_6,
    fehlm_7,
    fehlj_7,
    fehltg_7,
    fehlutg_7,
    fehlst_7,
    fehlfust_7,
    fehlm_8,
    fehlj_8,
    fehltg_8,
    fehlutg_8,
    fehlst_8,
    fehlfust_8,
    fehlm_9,
    fehlj_9,
    fehltg_9,
    fehlutg_9,
    fehlst_9,
    fehlfust_9,
    fehlm_10,
    fehlj_10,
    fehltg_10,
    fehlutg_10,
    fehlst_10,
    fehlfust_10,
    fehlm_11,
    fehlj_11,
    fehltg_11,
    fehlutg_11,
    fehlst_11,
    fehlfust_11,
    fehlm_12,
    fehlj_12,
    fehltg_12,
    fehlutg_12,
    fehlst_12,
    fehlfust_12,
    fehlm_13,
    fehlj_13,
    fehltg_13,
    fehlutg_13,
    fehlst_13,
    fehlfust_13,
    fehlm_14,
    fehlj_14,
    fehltg_14,
    fehlutg_14,
    fehlst_14,
    fehlfust_14,
    fehlm_15,
    fehlj_15,
    fehltg_15,
    fehlutg_15,
    fehlst_15,
    fehlfust_15,
    fehlm_16,
    fehlj_16,
    fehltg_16,
    fehlutg_16,
    fehlst_16,
    fehlfust_16,
    fehlm_17,
    fehlj_17,
    fehltg_17,
    fehlutg_17,
    fehlst_17,
    fehlfust_17,
    fehlm_18,
    fehlj_18,
    fehltg_18,
    fehlutg_18,
    fehlst_18,
    fehlfust_18,
    NULL::TEXT AS probleme_a,
    NULL::TEXT AS probleme_b,
    NULL::TEXT AS probleme_c,
    NULL::TEXT AS probleme_d,
    NULL::TEXT AS probleme_e,
    NULL::VARCHAR(256) AS probleme_f_t,
    NULL::TEXT AS probleme_f,
    zielcm_schul_a,
    zielcm_schul_b,
    zielcm_schul_c,
    zielcm_schul_d,
    zielcm_schul_e,
    zielcm_schul_f,
    zielcm_schul_g,
    zielcm_schul_h,
    NULL::VARCHAR(256) AS zielcm_schul_h_t,
    zielcm_sozial_a,
    zielcm_sozial_b,
    zielcm_sozial_c,
    zielcm_sozial_d,
    zielcm_sozial_e,
    zielcm_sozial_f,
    zielcm_sozial_g,
    zielcm_sozial_h,
    NULL::VARCHAR(256) AS zielcm_sozial_h_t,
    hilfm_1,
    hilfm_art_1,
    hash_value(hilfm_inst_1, hilfm_inst_1) AS hilfm_inst_1,
    hash_value(hilfm_einr_1, hilfm_einr_1) AS hilfm_einr_1,
    hilfm_start_1,
    hilfm_ende_1,
    hilfm_umf_1,
    hilfm_ziel_1_1,
    hilfm_zeit_1_1,
    hilfm_erreicht_1_1,
    hilfm_ziel_1_2,
    hilfm_zeit_1_2,
    hilfm_erreicht_1_2,
    hilfm_ziel_1_3,
    hilfm_zeit_1_3,
    hilfm_erreicht_1_3,
    NULL::TEXT AS hilfm_sf_1,
    hilfm_2,
    hilfm_art_2,
    hash_value(hilfm_inst_2, hilfm_inst_2) AS hilfm_inst_2,
    hash_value(hilfm_einr_2, hilfm_einr_2) AS hilfm_einr_2,
    hilfm_start_2,
    hilfm_ende_2,
    hilfm_umf_2,
    hilfm_ziel_2_1,
    hilfm_zeit_2_1,
    hilfm_erreicht_2_1,
    hilfm_ziel_2_2,
    hilfm_zeit_2_2,
    hilfm_erreicht_2_2,
    hilfm_ziel_2_3,
    hilfm_zeit_2_3,
    hilfm_erreicht_2_3,
    NULL::TEXT AS hilfm_sf_2,
    hilfm_3,
    hilfm_art_3,
    hash_value(hilfm_inst_3, hilfm_inst_3) AS hilfm_inst_3,
    hash_value(hilfm_einr_3, hilfm_einr_3) AS hilfm_einr_3,
    hilfm_start_3,
    hilfm_ende_3,
    hilfm_umf_3,
    hilfm_ziel_3_1,
    hilfm_zeit_3_1,
    hilfm_erreicht_3_1,
    hilfm_ziel_3_2,
    hilfm_zeit_3_2,
    hilfm_erreicht_3_2,
    hilfm_ziel_3_3,
    hilfm_zeit_3_3,
    hilfm_erreicht_3_3,
    NULL::TEXT AS hilfm_sf_3,
    NULL::TEXT AS hilfm_weitere,
    NULL::TEXT AS vereinb_a,
    NULL::TEXT AS vereinb_b,
    NULL::TEXT AS vereinb_c,
    NULL::TEXT AS vereinb_d,
    NULL::TEXT AS vereinb_e,
    NULL::VARCHAR(256) AS vereinb_f_t,
    NULL::TEXT AS vereinb_f,
    elt_koop,
    elt_ziel_a,
    elt_zerr_a,
    NULL::TEXT AS elt_sf_a,
    elt_ziel_b,
    elt_zerr_b,
    NULL::TEXT AS elt_sf_b,
    elt_ziel_c,
    elt_zerr_c,
    NULL::TEXT AS elt_sf_c,
    elt_ziel_d,
    elt_zerr_d,
    NULL::TEXT AS elt_sf_d,
    elt_ziel_e,
    elt_zerr_e,
    NULL::TEXT AS elt_sf_e,
    elt_ziel_f,
    elt_zerr_f,
    NULL::TEXT AS elt_sf_f,
    elt_ziel_g,
    elt_zerr_g,
    NULL::TEXT AS elt_sf_g,
    elt_ziel_h,
    elt_zerr_h,
    NULL::TEXT AS elt_sf_h,
    elt_ziel_i_t,
    elt_ziel_i,
    elt_zerr_i,
    NULL::TEXT AS elt_sf_i,
    elt_mn_a,
    elt_mn_b,
    elt_mn_c,
    elt_mn_d,
    elt_mn_e,
    elt_mn_f,
    elt_mn_g,
    elt_mn_h,
    elt_mn_i,
    elt_mn_j,
    NULL::VARCHAR(256) AS elt_mn_j_t,
    NULL::TEXT AS dok_cm,
    cm_datum_verlaengerung_1,
    cm_bestaet_verlaengerung_1,
    NULL::TEXT AS cm_anmerk_verlaengerung_1,
    cm_datum_verlaengerung_2,
    cm_bestaet_verlaengerung_2,
    NULL::TEXT AS cm_anmerk_verlaengerung_2,
    datum_cm_ende,
    cm_zeit,
    cm_kontakt,
    cm_kontakt_sonstige,
    NULL::VARCHAR(256) AS cm_kontakt_sonstige_t,
    beschul_end_a,
    beschul_end_b,
    beschul_end_c,
    beschul_end_d,
    beschul_end_e,
    beschul_end_f,
    beschul_end_h,
    beschul_end_h_t,
    uleistung_ende,
    uleistung_ende_a,
    uleistung_ende_b,
    uleistung_ende_c,
    uleistung_ende_d,
    uleistung_ende_e,
    uleistung_ende_f,
    uleistung_ende_g,
    uleistung_ende_h,
    uleistung_ende_i,
    uleistung_ende_j,
    NULL::VARCHAR(256) AS uleistung_ende_j_t,
    cm_end_art,
    cm_end_verm,
    NULL::VARCHAR(256) AS cm_end_verm_t,
    cm_end_schul,
    NULL::VARCHAR(256) AS cm_end_schul_t,
    cm_end_jg,
    NULL::VARCHAR(256) AS cm_schule_name,
    NULL::VARCHAR(256) AS cm_schule_strasse,
    NULL::VARCHAR(256) AS cm_schule_strassenr,
    NULL::VARCHAR(256) AS cm_schule_plz,
    NULL::VARCHAR(256) AS cm_schule_ort,
    NULL::VARCHAR(256) AS cm_schule_person_1,
    NULL::VARCHAR(256) AS cm_schule_person_2,
    cm_end_sonst,
    NULL::VARCHAR(256) AS cm_end_sonst_t,
    cm_end_ab,
    cm_end_abgr,
    NULL::VARCHAR(256) AS cm_end_abgr_t,
    cm_ziel,
    cm_schulbes_1,
    cm_schulbes_2,
    cm_zielsch_a,
    cm_zielsch_b,
    cm_zielsch_c,
    cm_zielsch_d,
    cm_zielsch_e,
    cm_zielsch_f,
    cm_zielsch_g,
    cm_zielsch_h,
    NULL::VARCHAR(256) AS cm_zielsch_h_t,
    cm_zielsoz_a,
    cm_zielsoz_b,
    cm_zielsoz_c,
    cm_zielsoz_d,
    cm_zielsoz_e,
    cm_zielsoz_f,
    cm_zielsoz_g,
    cm_zielsoz_h,
    NULL::VARCHAR(256) AS cm_zielsoz_h_t,
    NULL::TEXT AS dok_ziel,
    nbtr,
    nbetr_start,
    nbetr_ende,
    NULL::TEXT AS nbetr_mn,
    nbetr_verbl,
    NULL::VARCHAR(256) AS nbetr_verbl_t,
    NULL::TEXT AS dok_abschl FROM master_tbl_view;

CREATE OR REPLACE RULE master_tbl_anonym_delete_rule AS ON DELETE TO master_tbl_anonym_view
    DO INSTEAD NOTHING;

CREATE OR REPLACE RULE master_tbl_anonym_insert_rule AS ON INSERT TO master_tbl_anonym_view
    DO INSTEAD NOTHING;

GRANT SELECT ON master_tbl_anonym_view TO GROUP :cm_group;
GRANT SELECT ON master_tbl_anonym_view TO GROUP :admin_group;


CREATE OR REPLACE RULE master_tbl_update_rule AS ON UPDATE TO master_tbl_view
DO INSTEAD UPDATE master_tbl SET
    einwilligung = NEW.einwilligung,
    phase = NEW.phase,
    fkz = NEW.fkz,
    ks = NEW.ks,
    fn = NEW.fn,
    mitarb_zv = NEW.mitarb_zv,
    mitarb_zn = NEW.mitarb_zn,
    mitarb_vv = NEW.mitarb_vv,
    mitarb_vn = NEW.mitarb_vn,
    name = NEW.name,
    vorname = NEW.vorname,
    geschlecht = NEW.geschlecht,
    geburtsdatum = NEW.geburtsdatum,
    kontakt = NEW.kontakt,
    erstgespraech = NEW.erstgespraech,
    zugang = NEW.zugang,
    zugang_t = NEW.zugang_t,
    cm2c = NEW.cm2c,
    cm_dok_datum_beendigung = NEW.cm_dok_datum_beendigung,
    cm_dok_end_art = NEW.cm_dok_end_art,
    cm_dok_end_verm = NEW.cm_dok_end_verm,
    cm_dok_end_sonst = NEW.cm_dok_end_sonst,
    cm_neuauf_genehm = NEW.cm_neuauf_genehm,
    cm_wiederauf_genehm_1 = NEW.cm_wiederauf_genehm_1,
    cm_wiederauf_genehm_datum_1 = NEW.cm_wiederauf_genehm_datum_1,
    cm_wiederauf_datum_bis_1 = NEW.cm_wiederauf_datum_bis_1,
    cm_wiederauf_genehm_2 = NEW.cm_wiederauf_genehm_2,
    cm_wiederauf_datum_bis_2 = NEW.cm_wiederauf_datum_bis_2,
    cm2c_t = NEW.cm2c_t,
    kd_schule_name_1 = NEW.kd_schule_name_1,
    kd_schule_strasse_1 = NEW.kd_schule_strasse_1,
    kd_schule_strassenr_1 = NEW.kd_schule_strassenr_1,
    kd_schule_plz_1 = NEW.kd_schule_plz_1,
    kd_schule_ort_1 = NEW.kd_schule_ort_1,
    kd_schule_vorwahl_1 = NEW.kd_schule_vorwahl_1,
    kd_schule_telefonnummer_1 = NEW.kd_schule_telefonnummer_1,
    kd_schule_email_1 = NEW.kd_schule_email_1,
    bezugs_name_1 = NEW.bezugs_name_1,
    bezugs_vorname_1 = NEW.bezugs_vorname_1,
    bezugs_vorwahl_1 = NEW.bezugs_vorwahl_1,
    bezugs_telefonnummer_1 = NEW.bezugs_telefonnummer_1,
    bezugs_email_1 = NEW.bezugs_email_1,
    kd_jugendamt_kundennummer_1 = NEW.kd_jugendamt_kundennummer_1,
    kd_jugendamt_strasse_1 = NEW.kd_jugendamt_strasse_1,
    kd_jugendamt_strassenr_1 = NEW.kd_jugendamt_strassenr_1,
    kd_jugendamt_plz_1 = NEW.kd_jugendamt_plz_1,
    kd_jugendamt_ort_1 = NEW.kd_jugendamt_ort_1,
    kd_jugendamt_vorwahl_1 = NEW.kd_jugendamt_vorwahl_1,
    kd_jugendamt_telefonnummer_1 = NEW.kd_jugendamt_telefonnummer_1,
    kd_jugendamt_email_1 = NEW.kd_jugendamt_email_1,
    kd_institution_name_1 = NEW.kd_institution_name_1,
    kd_institution_kundennummer_1 = NEW.kd_institution_kundennummer_1,
    kd_institution_strasse_1 = NEW.kd_institution_strasse_1,
    kd_institution_strassenr_1 = NEW.kd_institution_strassenr_1,
    kd_institution_plz_1 = NEW.kd_institution_plz_1,
    kd_institution_ort_1 = NEW.kd_institution_ort_1,
    kd_institution_vorwahl_1 = NEW.kd_institution_vorwahl_1,
    kd_institution_telefonnummer_1 = NEW.kd_institution_telefonnummer_1,
    kd_institution_email_1 = NEW.kd_institution_email_1,
    kd_institution_name_2 = NEW.kd_institution_name_2,
    kd_institution_kundennummer_2 = NEW.kd_institution_kundennummer_2,
    kd_institution_strasse_2 = NEW.kd_institution_strasse_2,
    kd_institution_strassenr_2 = NEW.kd_institution_strassenr_2,
    kd_institution_plz_2 = NEW.kd_institution_plz_2,
    kd_institution_ort_2 = NEW.kd_institution_ort_2,
    kd_institution_vorwahl_2 = NEW.kd_institution_vorwahl_2,
    kd_institution_telefonnummer_2 = NEW.kd_institution_telefonnummer_2,
    kd_institution_email_2 = NEW.kd_institution_email_2,
    kd_institution_name_3 = NEW.kd_institution_name_3,
    kd_institution_kundennummer_3 = NEW.kd_institution_kundennummer_3,
    kd_institution_strasse_3 = NEW.kd_institution_strasse_3,
    kd_institution_strassenr_3 = NEW.kd_institution_strassenr_3,
    kd_institution_plz_3 = NEW.kd_institution_plz_3,
    kd_institution_ort_3 = NEW.kd_institution_ort_3,
    kd_institution_vorwahl_3 = NEW.kd_institution_vorwahl_3,
    kd_institution_telefonnummer_3 = NEW.kd_institution_telefonnummer_3,
    kd_institution_email_3 = NEW.kd_institution_email_3,
    dok_eingang = NEW.dok_eingang,
    datum_cm_start = NEW.datum_cm_start,
    addresse_strasse_1 = NEW.addresse_strasse_1,
    addresse_strassenr_1 = NEW.addresse_strassenr_1,
    addresse_plz_1 = NEW.addresse_plz_1,
    addresse_ort_1 = NEW.addresse_ort_1,
    addresse1_vorwahl_1 = NEW.addresse1_vorwahl_1,
    addresse1_telefonnummer_1 = NEW.addresse1_telefonnummer_1,
    addresse2_vorwahl_1 = NEW.addresse2_vorwahl_1,
    addresse2_telefonnummer_2 = NEW.addresse2_telefonnummer_2,
    addresse_weiteretelefonnummern_1 = NEW.addresse_weiteretelefonnummern_1,
    addresse_email_1 = NEW.addresse_email_1,
    wohnort = NEW.wohnort,
    wohnauf = NEW.wohnauf,
    wohnauf_t = NEW.wohnauf_t,
    kinder = NEW.kinder,
    kinder_hh = NEW.kinder_hh,
    kinder_allein = NEW.kinder_allein,
    nat_land = NEW.nat_land,
    nat_land_t = NEW.nat_land_t,
    nat_staat = NEW.nat_staat,
    nat_status = NEW.nat_status,
    nat_wohn = NEW.nat_wohn,
    nat_muspra = NEW.nat_muspra,
    nat_muspra_t = NEW.nat_muspra_t,
    nat_haspra = NEW.nat_haspra,
    psorge = NEW.psorge,
    psorge_t = NEW.psorge_t,
    mutter = NEW.mutter,
    mutter_n = NEW.mutter_n,
    mutter_vn = NEW.mutter_vn,
    mutter_gb = NEW.mutter_gb,
    mutter_strasse_1 = NEW.mutter_strasse_1,
    mutter_strassenr_1 = NEW.mutter_strassenr_1,
    mutter_plz_1 = NEW.mutter_plz_1,
    mutter_ort_1 = NEW.mutter_ort_1,
    mutter_vorwahl1_1 = NEW.mutter_vorwahl1_1,
    mutter_telefonnummer1_1 = NEW.mutter_telefonnummer1_1,
    mutter_vorwahl2_1 = NEW.mutter_vorwahl2_1,
    mutter_telefonnummer2_1 = NEW.mutter_telefonnummer2_1,
    mutter_email_1 = NEW.mutter_email_1,
    mutter_land = NEW.mutter_land,
    mutter_land_t = NEW.mutter_land_t,
    mutter_staat = NEW.mutter_staat,
    mutter_spra = NEW.mutter_spra,
    mutter_bildung = NEW.mutter_bildung,
    mutter_bildung_t = NEW.mutter_bildung_t,
    mutter_beruf = NEW.mutter_beruf,
    mutter_sonst = NEW.mutter_sonst,
    vater = NEW.vater,
    vater_n = NEW.vater_n,
    vater_vn = NEW.vater_vn,
    vater_gb = NEW.vater_gb,
    vater_strasse_1 = NEW.vater_strasse_1,
    vater_strassenr_1 = NEW.vater_strassenr_1,
    vater_plz_1 = NEW.vater_plz_1,
    vater_ort_1 = NEW.vater_ort_1,
    vater_vorwahl1_1 = NEW.vater_vorwahl1_1,
    vater_telefonnummer1_1 = NEW.vater_telefonnummer1_1,
    vater_vorwahl2_1 = NEW.vater_vorwahl2_1,
    vater_telefonnummer2_1 = NEW.vater_telefonnummer2_1,
    vater_email_1 = NEW.vater_email_1,
    vater_land = NEW.vater_land,
    vater_land_t = NEW.vater_land_t,
    vater_staat = NEW.vater_staat,
    vater_spra = NEW.vater_spra,
    vater_bildung = NEW.vater_bildung,
    vater_bildung_t = NEW.vater_bildung_t,
    vater_beruf = NEW.vater_beruf,
    vater_sonst = NEW.vater_sonst,
    geschw_vorhanden = NEW.geschw_vorhanden,
    geschw_w = NEW.geschw_w,
    geschw_m = NEW.geschw_m,
    geschw_hh = NEW.geschw_hh,
    geschw_alt_a = NEW.geschw_alt_a,
    geschw_alt_b = NEW.geschw_alt_b,
    geschw_alt_c = NEW.geschw_alt_c,
    geschw_alt_d = NEW.geschw_alt_d,
    einkommen_a = NEW.einkommen_a,
    einkommen_b = NEW.einkommen_b,
    einkommen_c = NEW.einkommen_c,
    einkommen_e = NEW.einkommen_e,
    einkommen_d = NEW.einkommen_d,
    einkommen_d_t = NEW.einkommen_d_t,
    bezugsperson_a = NEW.bezugsperson_a,
    bezugsperson_b = NEW.bezugsperson_b,
    bezugsperson_c = NEW.bezugsperson_c,
    bezugsperson_d = NEW.bezugsperson_d,
    bezugsperson_e = NEW.bezugsperson_e,
    bezugsperson_f = NEW.bezugsperson_f,
    bezugsperson_g = NEW.bezugsperson_g,
    bezugsperson_h = NEW.bezugsperson_h,
    bezugsperson_i = NEW.bezugsperson_i,
    bezugsperson_j = NEW.bezugsperson_j,
    bezugsperson_k = NEW.bezugsperson_k,
    bezugsperson_l = NEW.bezugsperson_l,
    bezugsperson_m = NEW.bezugsperson_m,
    bezugsperson_n = NEW.bezugsperson_n,
    bezugsperson_o = NEW.bezugsperson_o,
    bezugsperson_p = NEW.bezugsperson_p,
    bezugsperson_q = NEW.bezugsperson_q,
    bezugsperson_r = NEW.bezugsperson_r,
    bezugsperson_r_t = NEW.bezugsperson_r_t,
    kd_bezug_name_1 = NEW.kd_bezug_name_1,
    kd_bezug_vorname_1 = NEW.kd_bezug_vorname_1,
    kd_bezug_funktion_1 = NEW.kd_bezug_funktion_1,
    kd_bezug_strasse_1 = NEW.kd_bezug_strasse_1,
    kd_bezug_strassenr_1 = NEW.kd_bezug_strassenr_1,
    kd_bezug_plz_1 = NEW.kd_bezug_plz_1,
    kd_bezug_ort_1 = NEW.kd_bezug_ort_1,
    kd_bezug_1_vorwahl = NEW.kd_bezug_1_vorwahl,
    kd_bezug_1_telefon = NEW.kd_bezug_1_telefon,
    kd_bezug_email_1 = NEW.kd_bezug_email_1,
    kd_bezug_name_2 = NEW.kd_bezug_name_2,
    kd_bezug_vorname_2 = NEW.kd_bezug_vorname_2,
    kd_bezug_funktion_2 = NEW.kd_bezug_funktion_2,
    kd_bezug_strasse_2 = NEW.kd_bezug_strasse_2,
    kd_bezug_strassenr_2 = NEW.kd_bezug_strassenr_2,
    kd_bezug_plz_2 = NEW.kd_bezug_plz_2,
    kd_bezug_ort_2 = NEW.kd_bezug_ort_2,
    kd_bezug_2_vorwahl = NEW.kd_bezug_2_vorwahl,
    kd_bezug_2_telefon = NEW.kd_bezug_2_telefon,
    kd_bezug_email_2 = NEW.kd_bezug_email_2,
    kd_bezug_name_3 = NEW.kd_bezug_name_3,
    kd_bezug_vorname_3 = NEW.kd_bezug_vorname_3,
    kd_bezug_funktion_3 = NEW.kd_bezug_funktion_3,
    kd_bezug_strasse_3 = NEW.kd_bezug_strasse_3,
    kd_bezug_strassenr_3 = NEW.kd_bezug_strassenr_3,
    kd_bezug_plz_3 = NEW.kd_bezug_plz_3,
    kd_bezug_ort_3 = NEW.kd_bezug_ort_3,
    kd_bezug_3_vorwahl = NEW.kd_bezug_3_vorwahl,
    kd_bezug_3_telefon = NEW.kd_bezug_3_telefon,
    kd_bezug_email_3 = NEW.kd_bezug_email_3,
    zugeh_a = NEW.zugeh_a,
    zugeh_b = NEW.zugeh_b,
    zugeh_c = NEW.zugeh_c,
    zugeh_d = NEW.zugeh_d,
    dok_angaben = NEW.dok_angaben,
    schulform = NEW.schulform,
    schulform_t = NEW.schulform_t,
    klassenstufe = NEW.klassenstufe,
    klassenwdh = NEW.klassenwdh,
    sinteresse_a = NEW.sinteresse_a,
    sinteresse_b = NEW.sinteresse_b,
    leistung_ges = NEW.leistung_ges,
    leistung_d = NEW.leistung_d,
    leistung_m = NEW.leistung_m,
    leistung_fs = NEW.leistung_fs,
    sv_aktiv = NEW.sv_aktiv,
    sv_passiv = NEW.sv_passiv,
    sv_a = NEW.sv_a,
    sv_b = NEW.sv_b,
    sv_c = NEW.sv_c,
    sv_d = NEW.sv_d,
    sv_e = NEW.sv_e,
    sv_f = NEW.sv_f,
    sv_g = NEW.sv_g,
    sv_g_t = NEW.sv_g_t,
    fehltg_sj = NEW.fehltg_sj,
    fehltg_sj_ue = NEW.fehltg_sj_ue,
    fehltg_m = NEW.fehltg_m,
    fehltg_m_ue = NEW.fehltg_m_ue,
    fehlst_sj = NEW.fehlst_sj,
    fehlst_sj_ue = NEW.fehlst_sj_ue,
    fehlst_m = NEW.fehlst_m,
    fehlst_m_ue = NEW.fehlst_m_ue,
    sv_monate = NEW.sv_monate,
    abschl_gef = NEW.abschl_gef,
    abschl_pr = NEW.abschl_pr,
    ordmn = NEW.ordmn,
    ekomp_a = NEW.ekomp_a,
    ekomp_b = NEW.ekomp_b,
    ekomp_c = NEW.ekomp_c,
    ekomp_d = NEW.ekomp_d,
    ekomp_e = NEW.ekomp_e,
    ekomp_f = NEW.ekomp_f,
    ekomp_g = NEW.ekomp_g,
    ekomp_h = NEW.ekomp_h,
    ekomp_i = NEW.ekomp_i,
    ekomp_i_t = NEW.ekomp_i_t,
    problfam_a = NEW.problfam_a,
    problfam_b = NEW.problfam_b,
    problfam_c = NEW.problfam_c,
    problfam_d = NEW.problfam_d,
    problfam_e = NEW.problfam_e,
    problfam_f = NEW.problfam_f,
    problfam_g = NEW.problfam_g,
    problfam_h = NEW.problfam_h,
    problfam_i = NEW.problfam_i,
    problfam_j = NEW.problfam_j,
    problfam_k = NEW.problfam_k,
    problfam_l = NEW.problfam_l,
    problfam_m = NEW.problfam_m,
    problfam_m_t = NEW.problfam_m_t,
    familie_anm = NEW.familie_anm,
    uleistung_beginn = NEW.uleistung_beginn,
    uleistung_beginn_a = NEW.uleistung_beginn_a,
    uleistung_beginn_b = NEW.uleistung_beginn_b,
    uleistung_beginn_c = NEW.uleistung_beginn_c,
    uleistung_beginn_d = NEW.uleistung_beginn_d,
    uleistung_beginn_e = NEW.uleistung_beginn_e,
    uleistung_beginn_f = NEW.uleistung_beginn_f,
    uleistung_beginn_g = NEW.uleistung_beginn_g,
    uleistung_beginn_h = NEW.uleistung_beginn_h,
    uleistung_beginn_i = NEW.uleistung_beginn_i,
    uleistung_beginn_j = NEW.uleistung_beginn_j,
    uleistung_beginn_j_t = NEW.uleistung_beginn_j_t,
    uleistung_verg = NEW.uleistung_verg,
    uleistung_anm = NEW.uleistung_anm,
    dok_biograf = NEW.dok_biograf,
    datum_kf_1 = NEW.datum_kf_1,
    kf_verfahren_1 = NEW.kf_verfahren_1,
    kf_anbiet_1 = NEW.kf_anbiet_1,
    kf_meth_a_1 = NEW.kf_meth_a_1,
    kf_meth_b_1 = NEW.kf_meth_b_1,
    kf_meth_d_1 = NEW.kf_meth_d_1,
    kf_meth_e_1 = NEW.kf_meth_e_1,
    kf_meth_f_1 = NEW.kf_meth_f_1,
    kf_meth_f_t_1 = NEW.kf_meth_f_t_1,
    kf_test_a_1 = NEW.kf_test_a_1,
    kf_test_a_t_1 = NEW.kf_test_a_t_1,
    kf_test_b_1 = NEW.kf_test_b_1,
    kf_test_b_t_1 = NEW.kf_test_b_t_1,
    kf_test_c_1 = NEW.kf_test_c_1,
    kf_test_c_t_1 = NEW.kf_test_c_t_1,
    kf_test_d_1 = NEW.kf_test_d_1,
    kf_test_d_t_1 = NEW.kf_test_d_t_1,
    komp_schule_a_1 = NEW.komp_schule_a_1,
    komp_schule_b_1 = NEW.komp_schule_b_1,
    komp_schule_c_1 = NEW.komp_schule_c_1,
    komp_schule_d_1 = NEW.komp_schule_d_1,
    komp_schule_e_1 = NEW.komp_schule_e_1,
    komp_schule_f_1 = NEW.komp_schule_f_1,
    komp_schule_g_1 = NEW.komp_schule_g_1,
    komp_schule_g_t_1 = NEW.komp_schule_g_t_1,
    komp_deutsch_a_1 = NEW.komp_deutsch_a_1,
    komp_deutsch_b_1 = NEW.komp_deutsch_b_1,
    komp_deutsch_c_1 = NEW.komp_deutsch_c_1,
    komp_deutsch_d_1 = NEW.komp_deutsch_d_1,
    komp_herkunft_1 = NEW.komp_herkunft_1,
    komp_sozial_a_1 = NEW.komp_sozial_a_1,
    komp_sozial_b_1 = NEW.komp_sozial_b_1,
    komp_sozial_c_1 = NEW.komp_sozial_c_1,
    komp_sozial_d_1 = NEW.komp_sozial_d_1,
    komp_sozial_e_1 = NEW.komp_sozial_e_1,
    komp_sozial_f_1 = NEW.komp_sozial_f_1,
    komp_sozial_g_1 = NEW.komp_sozial_g_1,
    komp_sozial_g_t_1 = NEW.komp_sozial_g_t_1,
    komp_selbst_a_1 = NEW.komp_selbst_a_1,
    komp_selbst_b_1 = NEW.komp_selbst_b_1,
    komp_selbst_c_1 = NEW.komp_selbst_c_1,
    komp_selbst_d_1 = NEW.komp_selbst_d_1,
    komp_selbst_e_1 = NEW.komp_selbst_e_1,
    komp_selbst_f_1 = NEW.komp_selbst_f_1,
    komp_selbst_g_1 = NEW.komp_selbst_g_1,
    komp_selbst_g_t_1 = NEW.komp_selbst_g_t_1,
    komp_psy_a_1 = NEW.komp_psy_a_1,
    komp_psy_b_1 = NEW.komp_psy_b_1,
    komp_psy_c_1 = NEW.komp_psy_c_1,
    komp_psy_d_1 = NEW.komp_psy_d_1,
    komp_psy_e_1 = NEW.komp_psy_e_1,
    komp_psy_f_1 = NEW.komp_psy_f_1,
    komp_psy_g_1 = NEW.komp_psy_g_1,
    komp_psy_g_t_1 = NEW.komp_psy_g_t_1,
    komp_anm = NEW.komp_anm,
    entw_a_1 = NEW.entw_a_1,
    entw_b_1 = NEW.entw_b_1,
    entw_c_1 = NEW.entw_c_1,
    entw_d_1 = NEW.entw_d_1,
    entw_e_1 = NEW.entw_e_1,
    entw_f_1 = NEW.entw_f_1,
    entw_g_1 = NEW.entw_g_1,
    entw_h_1 = NEW.entw_h_1,
    entw_h_t_1 = NEW.entw_h_t_1,
    entw_i_1 = NEW.entw_i_1,
    entw_i_t_1 = NEW.entw_i_t_1,
    entw_j_1 = NEW.entw_j_1,
    entw_j_t_1 = NEW.entw_j_t_1,
    entw_k_1 = NEW.entw_k_1,
    entw_k_t_1 = NEW.entw_k_t_1,
    entw_beh = NEW.entw_beh,
    dok_entw = NEW.dok_entw,
    datum_bfplan = NEW.datum_bfplan,
    beschul_a = NEW.beschul_a,
    beschul_b = NEW.beschul_b,
    beschul_c = NEW.beschul_c,
    beschul_d = NEW.beschul_d,
    beschul_e = NEW.beschul_e,
    beschul_f = NEW.beschul_f,
    beschul_h = NEW.beschul_h,
    beschul_h_t = NEW.beschul_h_t,
    reint_ziel = NEW.reint_ziel,
    reint_ziel_t = NEW.reint_ziel_t,
    reint_beding_a = NEW.reint_beding_a,
    reint_beding_b = NEW.reint_beding_b,
    reint_beding_c = NEW.reint_beding_c,
    reint_beding_d_t = NEW.reint_beding_d_t,
    reint_beding_d = NEW.reint_beding_d,
    fehlm_1 = NEW.fehlm_1,
    fehlj_1 = NEW.fehlj_1,
    fehltg_1 = NEW.fehltg_1,
    fehlutg_1 = NEW.fehlutg_1,
    fehlst_1 = NEW.fehlst_1,
    fehlfust_1 = NEW.fehlfust_1,
    fehlm_2 = NEW.fehlm_2,
    fehlj_2 = NEW.fehlj_2,
    fehltg_2 = NEW.fehltg_2,
    fehlutg_2 = NEW.fehlutg_2,
    fehlst_2 = NEW.fehlst_2,
    fehlfust_2 = NEW.fehlfust_2,
    fehlm_3 = NEW.fehlm_3,
    fehlj_3 = NEW.fehlj_3,
    fehltg_3 = NEW.fehltg_3,
    fehlutg_3 = NEW.fehlutg_3,
    fehlst_3 = NEW.fehlst_3,
    fehlfust_3 = NEW.fehlfust_3,
    fehlm_4 = NEW.fehlm_4,
    fehlj_4 = NEW.fehlj_4,
    fehltg_4 = NEW.fehltg_4,
    fehlutg_4 = NEW.fehlutg_4,
    fehlst_4 = NEW.fehlst_4,
    fehlfust_4 = NEW.fehlfust_4,
    fehlm_5 = NEW.fehlm_5,
    fehlj_5 = NEW.fehlj_5,
    fehltg_5 = NEW.fehltg_5,
    fehlutg_5 = NEW.fehlutg_5,
    fehlst_5 = NEW.fehlst_5,
    fehlfust_5 = NEW.fehlfust_5,
    fehlm_6 = NEW.fehlm_6,
    fehlj_6 = NEW.fehlj_6,
    fehltg_6 = NEW.fehltg_6,
    fehlutg_6 = NEW.fehlutg_6,
    fehlst_6 = NEW.fehlst_6,
    fehlfust_6 = NEW.fehlfust_6,
    fehlm_7 = NEW.fehlm_7,
    fehlj_7 = NEW.fehlj_7,
    fehltg_7 = NEW.fehltg_7,
    fehlutg_7 = NEW.fehlutg_7,
    fehlst_7 = NEW.fehlst_7,
    fehlfust_7 = NEW.fehlfust_7,
    fehlm_8 = NEW.fehlm_8,
    fehlj_8 = NEW.fehlj_8,
    fehltg_8 = NEW.fehltg_8,
    fehlutg_8 = NEW.fehlutg_8,
    fehlst_8 = NEW.fehlst_8,
    fehlfust_8 = NEW.fehlfust_8,
    fehlm_9 = NEW.fehlm_9,
    fehlj_9 = NEW.fehlj_9,
    fehltg_9 = NEW.fehltg_9,
    fehlutg_9 = NEW.fehlutg_9,
    fehlst_9 = NEW.fehlst_9,
    fehlfust_9 = NEW.fehlfust_9,
    fehlm_10 = NEW.fehlm_10,
    fehlj_10 = NEW.fehlj_10,
    fehltg_10 = NEW.fehltg_10,
    fehlutg_10 = NEW.fehlutg_10,
    fehlst_10 = NEW.fehlst_10,
    fehlfust_10 = NEW.fehlfust_10,
    fehlm_11 = NEW.fehlm_11,
    fehlj_11 = NEW.fehlj_11,
    fehltg_11 = NEW.fehltg_11,
    fehlutg_11 = NEW.fehlutg_11,
    fehlst_11 = NEW.fehlst_11,
    fehlfust_11 = NEW.fehlfust_11,
    fehlm_12 = NEW.fehlm_12,
    fehlj_12 = NEW.fehlj_12,
    fehltg_12 = NEW.fehltg_12,
    fehlutg_12 = NEW.fehlutg_12,
    fehlst_12 = NEW.fehlst_12,
    fehlfust_12 = NEW.fehlfust_12,
    fehlm_13 = NEW.fehlm_13,
    fehlj_13 = NEW.fehlj_13,
    fehltg_13 = NEW.fehltg_13,
    fehlutg_13 = NEW.fehlutg_13,
    fehlst_13 = NEW.fehlst_13,
    fehlfust_13 = NEW.fehlfust_13,
    fehlm_14 = NEW.fehlm_14,
    fehlj_14 = NEW.fehlj_14,
    fehltg_14 = NEW.fehltg_14,
    fehlutg_14 = NEW.fehlutg_14,
    fehlst_14 = NEW.fehlst_14,
    fehlfust_14 = NEW.fehlfust_14,
    fehlm_15 = NEW.fehlm_15,
    fehlj_15 = NEW.fehlj_15,
    fehltg_15 = NEW.fehltg_15,
    fehlutg_15 = NEW.fehlutg_15,
    fehlst_15 = NEW.fehlst_15,
    fehlfust_15 = NEW.fehlfust_15,
    fehlm_16 = NEW.fehlm_16,
    fehlj_16 = NEW.fehlj_16,
    fehltg_16 = NEW.fehltg_16,
    fehlutg_16 = NEW.fehlutg_16,
    fehlst_16 = NEW.fehlst_16,
    fehlfust_16 = NEW.fehlfust_16,
    fehlm_17 = NEW.fehlm_17,
    fehlj_17 = NEW.fehlj_17,
    fehltg_17 = NEW.fehltg_17,
    fehlutg_17 = NEW.fehlutg_17,
    fehlst_17 = NEW.fehlst_17,
    fehlfust_17 = NEW.fehlfust_17,
    fehlm_18 = NEW.fehlm_18,
    fehlj_18 = NEW.fehlj_18,
    fehltg_18 = NEW.fehltg_18,
    fehlutg_18 = NEW.fehlutg_18,
    fehlst_18 = NEW.fehlst_18,
    fehlfust_18 = NEW.fehlfust_18,
    probleme_a = NEW.probleme_a,
    probleme_b = NEW.probleme_b,
    probleme_c = NEW.probleme_c,
    probleme_d = NEW.probleme_d,
    probleme_e = NEW.probleme_e,
    probleme_f_t = NEW.probleme_f_t,
    probleme_f = NEW.probleme_f,
    zielcm_schul_a = NEW.zielcm_schul_a,
    zielcm_schul_b = NEW.zielcm_schul_b,
    zielcm_schul_c = NEW.zielcm_schul_c,
    zielcm_schul_d = NEW.zielcm_schul_d,
    zielcm_schul_e = NEW.zielcm_schul_e,
    zielcm_schul_f = NEW.zielcm_schul_f,
    zielcm_schul_g = NEW.zielcm_schul_g,
    zielcm_schul_h = NEW.zielcm_schul_h,
    zielcm_schul_h_t = NEW.zielcm_schul_h_t,
    zielcm_sozial_a = NEW.zielcm_sozial_a,
    zielcm_sozial_b = NEW.zielcm_sozial_b,
    zielcm_sozial_c = NEW.zielcm_sozial_c,
    zielcm_sozial_d = NEW.zielcm_sozial_d,
    zielcm_sozial_e = NEW.zielcm_sozial_e,
    zielcm_sozial_f = NEW.zielcm_sozial_f,
    zielcm_sozial_g = NEW.zielcm_sozial_g,
    zielcm_sozial_h = NEW.zielcm_sozial_h,
    zielcm_sozial_h_t = NEW.zielcm_sozial_h_t,
    hilfm_1 = NEW.hilfm_1,
    hilfm_art_1 = NEW.hilfm_art_1,
    hilfm_inst_1 = NEW.hilfm_inst_1,
    hilfm_einr_1 = NEW.hilfm_einr_1,
    hilfm_start_1 = NEW.hilfm_start_1,
    hilfm_ende_1 = NEW.hilfm_ende_1,
    hilfm_umf_1 = NEW.hilfm_umf_1,
    hilfm_ziel_1_1 = NEW.hilfm_ziel_1_1,
    hilfm_zeit_1_1 = NEW.hilfm_zeit_1_1,
    hilfm_erreicht_1_1 = NEW.hilfm_erreicht_1_1,
    hilfm_ziel_1_2 = NEW.hilfm_ziel_1_2,
    hilfm_zeit_1_2 = NEW.hilfm_zeit_1_2,
    hilfm_erreicht_1_2 = NEW.hilfm_erreicht_1_2,
    hilfm_ziel_1_3 = NEW.hilfm_ziel_1_3,
    hilfm_zeit_1_3 = NEW.hilfm_zeit_1_3,
    hilfm_erreicht_1_3 = NEW.hilfm_erreicht_1_3,
    hilfm_sf_1 = NEW.hilfm_sf_1,
    hilfm_2 = NEW.hilfm_2,
    hilfm_art_2 = NEW.hilfm_art_2,
    hilfm_inst_2 = NEW.hilfm_inst_2,
    hilfm_einr_2 = NEW.hilfm_einr_2,
    hilfm_start_2 = NEW.hilfm_start_2,
    hilfm_ende_2 = NEW.hilfm_ende_2,
    hilfm_umf_2 = NEW.hilfm_umf_2,
    hilfm_ziel_2_1 = NEW.hilfm_ziel_2_1,
    hilfm_zeit_2_1 = NEW.hilfm_zeit_2_1,
    hilfm_erreicht_2_1 = NEW.hilfm_erreicht_2_1,
    hilfm_ziel_2_2 = NEW.hilfm_ziel_2_2,
    hilfm_zeit_2_2 = NEW.hilfm_zeit_2_2,
    hilfm_erreicht_2_2 = NEW.hilfm_erreicht_2_2,
    hilfm_ziel_2_3 = NEW.hilfm_ziel_2_3,
    hilfm_zeit_2_3 = NEW.hilfm_zeit_2_3,
    hilfm_erreicht_2_3 = NEW.hilfm_erreicht_2_3,
    hilfm_sf_2 = NEW.hilfm_sf_2,
    hilfm_3 = NEW.hilfm_3,
    hilfm_art_3 = NEW.hilfm_art_3,
    hilfm_inst_3 = NEW.hilfm_inst_3,
    hilfm_einr_3 = NEW.hilfm_einr_3,
    hilfm_start_3 = NEW.hilfm_start_3,
    hilfm_ende_3 = NEW.hilfm_ende_3,
    hilfm_umf_3 = NEW.hilfm_umf_3,
    hilfm_ziel_3_1 = NEW.hilfm_ziel_3_1,
    hilfm_zeit_3_1 = NEW.hilfm_zeit_3_1,
    hilfm_erreicht_3_1 = NEW.hilfm_erreicht_3_1,
    hilfm_ziel_3_2 = NEW.hilfm_ziel_3_2,
    hilfm_zeit_3_2 = NEW.hilfm_zeit_3_2,
    hilfm_erreicht_3_2 = NEW.hilfm_erreicht_3_2,
    hilfm_ziel_3_3 = NEW.hilfm_ziel_3_3,
    hilfm_zeit_3_3 = NEW.hilfm_zeit_3_3,
    hilfm_erreicht_3_3 = NEW.hilfm_erreicht_3_3,
    hilfm_sf_3 = NEW.hilfm_sf_3,
    hilfm_weitere = NEW.hilfm_weitere,
    vereinb_a = NEW.vereinb_a,
    vereinb_b = NEW.vereinb_b,
    vereinb_c = NEW.vereinb_c,
    vereinb_d = NEW.vereinb_d,
    vereinb_e = NEW.vereinb_e,
    vereinb_f_t = NEW.vereinb_f_t,
    vereinb_f = NEW.vereinb_f,
    elt_koop = NEW.elt_koop,
    elt_ziel_a = NEW.elt_ziel_a,
    elt_zerr_a = NEW.elt_zerr_a,
    elt_sf_a = NEW.elt_sf_a,
    elt_ziel_b = NEW.elt_ziel_b,
    elt_zerr_b = NEW.elt_zerr_b,
    elt_sf_b = NEW.elt_sf_b,
    elt_ziel_c = NEW.elt_ziel_c,
    elt_zerr_c = NEW.elt_zerr_c,
    elt_sf_c = NEW.elt_sf_c,
    elt_ziel_d = NEW.elt_ziel_d,
    elt_zerr_d = NEW.elt_zerr_d,
    elt_sf_d = NEW.elt_sf_d,
    elt_ziel_e = NEW.elt_ziel_e,
    elt_zerr_e = NEW.elt_zerr_e,
    elt_sf_e = NEW.elt_sf_e,
    elt_ziel_f = NEW.elt_ziel_f,
    elt_zerr_f = NEW.elt_zerr_f,
    elt_sf_f = NEW.elt_sf_f,
    elt_ziel_g = NEW.elt_ziel_g,
    elt_zerr_g = NEW.elt_zerr_g,
    elt_sf_g = NEW.elt_sf_g,
    elt_ziel_h = NEW.elt_ziel_h,
    elt_zerr_h = NEW.elt_zerr_h,
    elt_sf_h = NEW.elt_sf_h,
    elt_ziel_i_t = NEW.elt_ziel_i_t,
    elt_ziel_i = NEW.elt_ziel_i,
    elt_zerr_i = NEW.elt_zerr_i,
    elt_sf_i = NEW.elt_sf_i,
    elt_mn_a = NEW.elt_mn_a,
    elt_mn_b = NEW.elt_mn_b,
    elt_mn_c = NEW.elt_mn_c,
    elt_mn_d = NEW.elt_mn_d,
    elt_mn_e = NEW.elt_mn_e,
    elt_mn_f = NEW.elt_mn_f,
    elt_mn_g = NEW.elt_mn_g,
    elt_mn_h = NEW.elt_mn_h,
    elt_mn_i = NEW.elt_mn_i,
    elt_mn_j = NEW.elt_mn_j,
    elt_mn_j_t = NEW.elt_mn_j_t,
    dok_cm = NEW.dok_cm,
    cm_datum_verlaengerung_1 = NEW.cm_datum_verlaengerung_1,
    cm_bestaet_verlaengerung_1 = NEW.cm_bestaet_verlaengerung_1,
    cm_anmerk_verlaengerung_1 = NEW.cm_anmerk_verlaengerung_1,
    cm_datum_verlaengerung_2 = NEW.cm_datum_verlaengerung_2,
    cm_bestaet_verlaengerung_2 = NEW.cm_bestaet_verlaengerung_2,
    cm_anmerk_verlaengerung_2 = NEW.cm_anmerk_verlaengerung_2,
    datum_cm_ende = NEW.datum_cm_ende,
    cm_zeit = NEW.cm_zeit,
    cm_kontakt = NEW.cm_kontakt,
    cm_kontakt_sonstige = NEW.cm_kontakt_sonstige,
    cm_kontakt_sonstige_t = NEW.cm_kontakt_sonstige_t,
    beschul_end_a = NEW.beschul_end_a,
    beschul_end_b = NEW.beschul_end_b,
    beschul_end_c = NEW.beschul_end_c,
    beschul_end_d = NEW.beschul_end_d,
    beschul_end_e = NEW.beschul_end_e,
    beschul_end_f = NEW.beschul_end_f,
    beschul_end_h = NEW.beschul_end_h,
    beschul_end_h_t = NEW.beschul_end_h_t,
    uleistung_ende = NEW.uleistung_ende,
    uleistung_ende_a = NEW.uleistung_ende_a,
    uleistung_ende_b = NEW.uleistung_ende_b,
    uleistung_ende_c = NEW.uleistung_ende_c,
    uleistung_ende_d = NEW.uleistung_ende_d,
    uleistung_ende_e = NEW.uleistung_ende_e,
    uleistung_ende_f = NEW.uleistung_ende_f,
    uleistung_ende_g = NEW.uleistung_ende_g,
    uleistung_ende_h = NEW.uleistung_ende_h,
    uleistung_ende_i = NEW.uleistung_ende_i,
    uleistung_ende_j = NEW.uleistung_ende_j,
    uleistung_ende_j_t = NEW.uleistung_ende_j_t,
    cm_end_art = NEW.cm_end_art,
    cm_end_verm = NEW.cm_end_verm,
    cm_end_verm_t = NEW.cm_end_verm_t,
    cm_end_schul = NEW.cm_end_schul,
    cm_end_schul_t = NEW.cm_end_schul_t,
    cm_end_jg = NEW.cm_end_jg,
    cm_schule_name = NEW.cm_schule_name,
    cm_schule_strasse = NEW.cm_schule_strasse,
    cm_schule_strassenr = NEW.cm_schule_strassenr,
    cm_schule_plz = NEW.cm_schule_plz,
    cm_schule_ort = NEW.cm_schule_ort,
    cm_schule_person_1 = NEW.cm_schule_person_1,
    cm_schule_person_2 = NEW.cm_schule_person_2,
    cm_end_sonst = NEW.cm_end_sonst,
    cm_end_sonst_t = NEW.cm_end_sonst_t,
    cm_end_ab = NEW.cm_end_ab,
    cm_end_abgr = NEW.cm_end_abgr,
    cm_end_abgr_t = NEW.cm_end_abgr_t,
    cm_ziel = NEW.cm_ziel,
    cm_schulbes_1 = NEW.cm_schulbes_1,
    cm_schulbes_2 = NEW.cm_schulbes_2,
    cm_zielsch_a = NEW.cm_zielsch_a,
    cm_zielsch_b = NEW.cm_zielsch_b,
    cm_zielsch_c = NEW.cm_zielsch_c,
    cm_zielsch_d = NEW.cm_zielsch_d,
    cm_zielsch_e = NEW.cm_zielsch_e,
    cm_zielsch_f = NEW.cm_zielsch_f,
    cm_zielsch_g = NEW.cm_zielsch_g,
    cm_zielsch_h = NEW.cm_zielsch_h,
    cm_zielsch_h_t = NEW.cm_zielsch_h_t,
    cm_zielsoz_a = NEW.cm_zielsoz_a,
    cm_zielsoz_b = NEW.cm_zielsoz_b,
    cm_zielsoz_c = NEW.cm_zielsoz_c,
    cm_zielsoz_d = NEW.cm_zielsoz_d,
    cm_zielsoz_e = NEW.cm_zielsoz_e,
    cm_zielsoz_f = NEW.cm_zielsoz_f,
    cm_zielsoz_g = NEW.cm_zielsoz_g,
    cm_zielsoz_h = NEW.cm_zielsoz_h,
    cm_zielsoz_h_t = NEW.cm_zielsoz_h_t,
    dok_ziel = NEW.dok_ziel,
    nbtr = NEW.nbtr,
    nbetr_start = NEW.nbetr_start,
    nbetr_ende = NEW.nbetr_ende,
    nbetr_mn = NEW.nbetr_mn,
    nbetr_verbl = NEW.nbetr_verbl,
    nbetr_verbl_t = NEW.nbetr_verbl_t,
    dok_abschl = NEW.dok_abschl
WHERE id = NEW.id;

CREATE OR REPLACE  VIEW master_tbl_incm_view AS
    SELECT * FROM master_tbl_view
        WHERE phase IN (2,3,4,5);

GRANT SELECT ON public.master_tbl_incm_view TO :cm_group;
GRANT SELECT ON public.master_tbl_incm_view TO :admin_group;



INSERT INTO db_history (beschreibung, zeitpunkt)
        VALUES ('1.0/familieneinkommen.sql', current_timestamp);

REVOKE ALL ON FUNCTION set_case_editor_name(varchar, varchar, integer) FROM PUBLIC;
GRANT EXECUTE ON FUNCTION set_case_editor_name(varchar, varchar, integer) 
                TO GROUP :admin_group;

COMMIT;
