# -*- coding: utf-8 -*-
#
# Copyright 2007, 2008 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls WASKA (CoMPUter-based case fiLeS -
# Web-Anwendungs-Server fuer Kompetenzagenturen).
#
# mpuls WASKA is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls WASKA is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls WASKA. If not, see <http://www.gnu.org/licenses/>.
#
# mpuls WASKA has been developed on behalf of the
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and
# European Social Fund resources.
#
# Authors:
# Torsten Irländer <torsten.irlaender@intevation.de>
# Sascha L. Teichmann <teichmann@intevation.de>
#

import logging

import formencode

from mpulsweb.lib.base import c, g, render, request, session
from mpulsweb.lib.security import checkRole
from mpulsweb.lib.helpers import format_date 

from mpulsweb.model.case import SessionCase, Agency
from mpulsweb.model.statement import PrivacyStatement

from mpulsweb.controllers.formularpage import convert2dic
from mpulsweb.controllers.case import CaseController as MpulsCaseController

from waskoweb.lib.validators import NewCaseForm, NeuaufnahmeCaseForm, \
     WiederaufnahmeCaseForm

log = logging.getLogger(__name__)

class CaseController(MpulsCaseController):

    @checkRole('cm_ka')
    def newAction(self):
        # TODO: Use htmlfill here!
        session_case = SessionCase()
        session_case.setData(request.params)

        session['case'] = session_case
        session.save()

        # Do we want to print the statement?
        if request.params.has_key('print'):
            c.print_version = 1
            statement = PrivacyStatement(session_case, Agency())
            c.content = statement.fillout()
            return render('privacy/default_statement.mako')

        # Or do we want to store the new case?
        elif request.params.has_key('save'):
            validator = NewCaseForm()
            try:
                form_result = validator.to_python(request.params)
                aufnahme_typ = form_result["aufnahme_typ"]

                if aufnahme_typ in (1, 2):
                    session['signed'] = bool(form_result.get('statement_signed'))
                    session.save()

                if aufnahme_typ == 1:
                    # Wiedernahme
                    c.form_errors = {}
                    return render('/casemanagement/wiederaufnahme.mako')
                if aufnahme_typ == 2:
                    # Neuaufnahme
                    c.form_errors = {}
                    return render('/casemanagement/neuaufnahme.mako')
                case = self._createCase(form_result) 
            except formencode.Invalid, error:
                log.debug("Invalid form data: %r", error)
                c.form_result = error.value
                c.form_errors = error.error_dict or {}
                return render('/casemanagement/new.mako')

        return self.select(str(case.id))

    @checkRole('cm_ka')
    def neuaufnahmeAction(self):
        try:
            session_case = session['case']
            signed       = session['signed']
        except KeyError:
            raise HTTPNotFound("case not found")

        # check extra params here!
        validator = NeuaufnahmeCaseForm()
        try:
            form_result = validator.to_python(request.params)
            form_result.update(session_case.getData())
            form_result['statement_signed'] = signed
            form_result['cm_neuauf_genehm'] = '1'
            form_result['cm2c']             = '1'
            form_result['cm_dok_end_art']   = '2'
            form_result['fn']               = '_NA'
            case = self._createCase(form_result)
            return self.select(str(case.id))
        except formencode.Invalid, error:
            form = render('/casemanagement/neuaufnahme.mako')
            return formencode.htmlfill.render(form,
                defaults = error.value,
                errors  = error.error_dict)

    @checkRole('cm_ka')
    def wiederaufnahmeAction(self):
        try:
            session_case = session['case']
            signed       = session['signed']
        except KeyError:
            raise HTTPNotFound("case not found")

        # check extra params here!
        validator = WiederaufnahmeCaseForm()
        try:
            form_result = validator.to_python(request.params)
            form_result.update(session_case.getData())
            
            # convert datefields back to strings:
            fields = ['cm_dok_datum_beendigung', 
                      'cm_wiederauf_genehm_datum_1', 
                      'cm_wiederauf_datum_bis_1']
            for k in fields:
                form_result[k] = format_date(form_result.get(k))
            form_result['statement_signed'] = signed
            form_result['cm_wiederauf_genehm_1'] = '1'
            form_result['cm2c']                  = '1'
            form_result['fn']                    = '_WA'
            form_result['cm_dok_end_art']        = '1'
            form_result['datum_cm_start']        = form_result['cm_wiederauf_genehm_datum_1']
            case = self._createCase(form_result)
            return self.select(str(case.id))
        except formencode.Invalid, error:
            form = render('/casemanagement/wiederaufnahme.mako')
            return formencode.htmlfill.render(form,
                defaults = error.value,
                errors  = error.error_dict)

# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
